@@ -65,7 +65,7 @@ static void AddFilesToList(const std::string& FileList, std::vector<std::string>
     }
 }
 
-static void AddInclPathsToList(const std::string& FileList, std::list<std::string>& PathNames)
+static void AddInclPathsToList(const std::string& FileList, std::list<std::string>* PathNames)
 {
     // to keep things initially simple, if the file can't be opened, just be
     // silent and move on
@@ -81,12 +81,19 @@ static void AddInclPathsToList(const std::string& FileList, std::list<std::strin
                 if (PathName[PathName.length()-1] != '/')
                     PathName += '/';
 
-                PathNames.push_back(PathName);
+                PathNames->push_back(PathName);
             }
         }
     }
 }
 
+static void AddPathsToSet(const std::string& FileName, std::set<std::string>* set)
+{
+    std::list<std::string> templist;
+    AddInclPathsToList(FileName, &templist);
+    set->insert(templist.begin(), templist.end());
+}
+
 CmdLineParser::CmdLineParser(Settings *settings)
     : _settings(settings)
     , _showHelp(false)
@@ -125,6 +132,10 @@ bool CmdLineParser::ParseFromArgs(int argc, const char* const argv[])
         else if (std::strcmp(argv[i], "--debug-fp") == 0)
             _settings->debugFalsePositive = true;
 
+        // (Experimental) exception handling inside cppcheck client
+        else if (std::strcmp(argv[i], "--exception-handling") == 0)
+            _settings->exceptionHandling = true;
+
         // Inconclusive checking (still in testing phase)
         else if (std::strcmp(argv[i], "--inconclusive") == 0)
             _settings->inconclusive = true;
@@ -435,7 +446,14 @@ bool CmdLineParser::ParseFromArgs(int argc, const char* const argv[])
             _settings->userIncludes.push_back(path);
         } else if (std::strncmp(argv[i], "--includes-file=", 16) == 0) {
             // open this file and read every input file (1 file name per line)
-            AddInclPathsToList(16 + argv[i], _settings->_includePaths);
+            AddInclPathsToList(16 + argv[i], &_settings->_includePaths);
+        } else if (std::strncmp(argv[i], "--config-exclude=",17) ==0) {
+            std::string path = argv[i] + 17;
+            path = Path::fromNativeSeparators(path);
+            _settings->configExcludePaths.insert(path);
+        } else if (std::strncmp(argv[i], "--config-excludes-file=", 23) == 0) {
+            // open this file and read every input file (1 file name per line)
+            AddPathsToSet(23 + argv[i], &_settings->configExcludePaths);
         }
 
         // file list specified
@@ -465,7 +483,7 @@ bool CmdLineParser::ParseFromArgs(int argc, const char* const argv[])
 
             if (!path.empty()) {
                 path = Path::fromNativeSeparators(path);
-                path = Path::simplifyPath(path.c_str());
+                path = Path::simplifyPath(path);
                 path = Path::removeQuotationMarks(path);
 
                 if (FileLister::isDirectory(path)) {
@@ -558,6 +576,29 @@ bool CmdLineParser::ParseFromArgs(int argc, const char* const argv[])
                 PrintMessage("cppcheck: argument for '-j' is allowed to be 10000 at max.");
                 return false;
             }
+        } else if (std::strncmp(argv[i], "-l", 2) == 0) {
+            std::string numberString;
+
+            // "-l 3"
+            if (std::strcmp(argv[i], "-l") == 0) {
+                ++i;
+                if (i >= argc || argv[i][0] == '-') {
+                    PrintMessage("cppcheck: argument to '-l' is missing.");
+                    return false;
+                }
+
+                numberString = argv[i];
+            }
+
+            // "-l3"
+            else
+                numberString = argv[i]+2;
+
+            std::istringstream iss(numberString);
+            if (!(iss >> _settings->_loadAverage)) {
+                PrintMessage("cppcheck: argument to '-l' is not a number.");
+                return false;
+            }
         }
 
         // print all possible error messages..
@@ -825,6 +866,13 @@ void CmdLineParser::PrintHelp()
               "                         First given path is searched for contained header\n"
               "                         files first. If paths are relative to source files,\n"
               "                         this is not needed.\n"
+              "    --config-exclude=<dir>\n"
+              "                         Path (prefix) to be excluded from configuration checking.\n"
+              "                         Preprocessor configurations defined in headers (but not sources)\n"
+              "                         matching the prefix will not be considered for evaluation\n"
+              "                         of configuration alternatives\n"
+              "    --config-excludes-file=<file>\n"
+              "                         A file that contains a list of config-excludes\n"
               "    --include=<file>\n"
               "                         Force inclusion of a file before the checked file. Can\n"
               "                         be used for example when checking the Linux kernel,\n"
@@ -844,6 +892,9 @@ void CmdLineParser::PrintHelp()
               "                         more comments, like: '// cppcheck-suppress warningId'\n"
               "                         on the lines before the warning to suppress.\n"
               "    -j <jobs>            Start [jobs] threads to do the checking simultaneously.\n"
+              "    -l <load>            Specifies that no new threads should be started if there\n"
+              "                         are other threads running and the load average is at least\n"
+              "                         load (ignored on non UNIX-like systems)\n"
               "    --language=<language>, -x <language>\n"
               "                         Forces cppcheck to check all files as the given\n"
               "                         language. Valid values are: c, c++\n"
