@@ -32,6 +32,23 @@
 #include <algorithm>
 #include <climits>
 
+#if defined(__GNUC__) && !defined(__MINGW32__) && !defined(__CYGWIN__)
+#define USE_UNIX_SIGNAL_HANDLING
+#include <execinfo.h>
+#include <cxxabi.h>
+#endif
+
+#ifdef USE_UNIX_SIGNAL_HANDLING
+#include <signal.h>
+#include <cstdio>
+#endif
+
+#if defined(_MSC_VER)
+#define USE_WINDOWS_SEH
+#include <Windows.h>
+#include <excpt.h>
+#endif
+
 CppCheckExecutor::CppCheckExecutor()
     : _settings(0), time1(0), errorlist(false)
 {
@@ -146,6 +163,7 @@ bool CppCheckExecutor::parseFromArgs(CppCheck *cppcheck, int argc, const char* c
 int CppCheckExecutor::check(int argc, const char* const argv[])
 {
     Preprocessor::missingIncludeFlag = false;
+    Preprocessor::missingSystemIncludeFlag = false;
 
     CppCheck cppCheck(*this, true);
 
@@ -156,6 +174,223 @@ int CppCheckExecutor::check(int argc, const char* const argv[])
         return EXIT_FAILURE;
     }
 
+    if (cppCheck.settings().exceptionHandling) {
+        return check_wrapper(cppCheck, argc, argv);
+    } else {
+        return check_internal(cppCheck, argc, argv);
+    }
+}
+
+#if defined(USE_UNIX_SIGNAL_HANDLING)
+/* (declare this list here, so it may be used in signal handlers in addition to main())
+ * A list of signals available in ISO C
+ * Check out http://pubs.opengroup.org/onlinepubs/009695399/basedefs/signal.h.html
+ * For now we only want to detect abnormal behaviour for a few selected signals:
+ */
+struct Signaltype {
+    int signalnumber;
+    const char *signalname;
+};
+#define DECLARE_SIGNAL(x) {x, #x}
+static const Signaltype listofsignals[] = {
+    // don't care: SIGABRT,
+    DECLARE_SIGNAL(SIGFPE),
+    DECLARE_SIGNAL(SIGILL),
+    DECLARE_SIGNAL(SIGINT),
+    DECLARE_SIGNAL(SIGSEGV),
+    // don't care: SIGTERM
+};
+
+/**
+ *  Simple helper function:
+ * \return size of array
+ * */
+template<typename T, int size>
+size_t GetArrayLength(const T(&)[size])
+{
+    return size;
+}
+
+// 32 vs. 64bit
+#define ADDRESSDISPLAYLENGTH ((sizeof(long)==8)?12:8)
+
+/*
+ * Try to print the callstack.
+ * That is very sensitive to the operating system, hardware, compiler and runtime!
+ */
+static void print_stacktrace(FILE* f, bool demangling)
+{
+#if defined(__GNUC__)
+    void *array[32]= {0}; // the less resources the better...
+    const int depth = backtrace(array, (int)GetArrayLength(array));
+    char **symbolstrings = backtrace_symbols(array, depth);
+    if (symbolstrings) {
+        fputs("Callstack:\n", f);
+        const int offset=3; // the first two entries are simply within our own exception handling code, third is within libc
+        for (int i = offset; i < depth; ++i) {
+            const char * const symbol = symbolstrings[i];
+            //fprintf(f, "\"%s\"\n", symbol);
+            char * realname = nullptr;
+            const char * const firstBracketName = strchr(symbol, '(');
+            const char * const firstBracketAddress = strchr(symbol, '[');
+            const char * const secondBracketAddress = strchr(firstBracketAddress, ']');
+            const char * const beginAddress = firstBracketAddress+3;
+            const int addressLen = int(secondBracketAddress-beginAddress);
+            const int padLen = int(ADDRESSDISPLAYLENGTH-addressLen);
+            //fprintf(f, "AddressDisplayLength=%d    addressLen=%d      padLen=%d\n", ADDRESSDISPLAYLENGTH, addressLen, padLen);
+            if (demangling && firstBracketName) {
+                const char * const plus = strchr(firstBracketName, '+');
+                if (plus && (plus>(firstBracketName+1))) {
+                    char input_buffer[512]= {0};
+                    strncpy(input_buffer, firstBracketName+1, plus-firstBracketName-1);
+                    char output_buffer[1024]= {0};
+                    size_t length = GetArrayLength(output_buffer);
+                    int status=0;
+                    realname = abi::__cxa_demangle(input_buffer, output_buffer, &length, &status); // non-NULL on success
+                }
+            }
+            fprintf(f, "#%d 0x",
+                    i-offset);
+            if (padLen>0)
+                fprintf(f, "%0*d",
+                        padLen, 0);
+            if (realname) {
+                fprintf(f, "%.*s in %s\n",
+                        (int)(secondBracketAddress-firstBracketAddress-3), firstBracketAddress+3,
+                        realname);
+            } else {
+                fprintf(f, "%.*s in %.*s\n",
+                        (int)(secondBracketAddress-firstBracketAddress-3), firstBracketAddress+3,
+                        (int)(firstBracketAddress-symbol), symbol);
+            }
+        }
+        free(symbolstrings);
+    } else {
+        fputs("Callstack could not be obtained\n", f);
+    }
+#endif
+}
+
+/*
+ * Simple mapping
+ */
+static const char *signal_name(int signo)
+{
+    for (size_t s=0; s<GetArrayLength(listofsignals); ++s) {
+        if (listofsignals[s].signalnumber==signo)
+            return listofsignals[s].signalname;
+    }
+    return "";
+}
+
+/*
+ * Entry pointer for signal handlers
+ */
+static void CppcheckSignalHandler(int signo, siginfo_t * info, void * /*context*/)
+{
+    const char * const signame=signal_name(signo);
+    bool bPrintCallstack=true;
+    FILE* f=stderr;
+    switch (signo) {
+    case SIGILL:
+        fprintf(f, "Internal error (caught signal %d=%s at 0x%p)\n",
+                signo, signame, info->si_addr);
+        break;
+    case SIGFPE:
+        fprintf(f, "Internal error (caught signal %d=%s at 0x%p)\n",
+                signo, signame, info->si_addr);
+        break;
+    case SIGSEGV:
+        fprintf(f, "Internal error (caught signal %d=%s at 0x%p)\n",
+                signo, signame, info->si_addr);
+        break;
+        /*
+         case SIGBUS:
+            fprintf(f, "Internal error (caught signal %d=%s at 0x%p)\n",
+                     signo, signame, info->si_addr);
+           break;
+         case SIGTRAP:
+           fprintf(f, "Internal error (caught signal %d=%s at 0x%p)\n",
+                    signo, signame, info->si_addr);
+           break;
+        */
+    case SIGINT:
+        bPrintCallstack=false;
+        break;
+    default:
+        fprintf(f, "Internal error (caught signal %d)\n",
+                signo);
+        break;
+    }
+    if (bPrintCallstack) {
+        print_stacktrace(f, true);
+        fputs("\nPlease report this to the cppcheck developers!\n", f);
+    }
+    abort();
+}
+#endif
+
+#ifdef USE_WINDOWS_SEH
+/*
+ * Any evaluation of the information about the exception needs to be done here!
+ */
+static int filterException(int code, PEXCEPTION_POINTERS ex)
+{
+    // TODO we should try to extract more information here
+    //   - address, read/write
+    switch (ex->ExceptionRecord->ExceptionCode) {
+    case EXCEPTION_ACCESS_VIOLATION:
+        fprintf(stderr, "Internal error (EXCEPTION_ACCESS_VIOLATION)\n");
+        break;
+    case EXCEPTION_IN_PAGE_ERROR:
+        fprintf(stderr, "Internal error (EXCEPTION_IN_PAGE_ERROR)\n");
+        break;
+    default:
+        fprintf(stderr, "Internal error (%d)\n",
+                code);
+        break;
+    }
+    return EXCEPTION_EXECUTE_HANDLER;
+}
+#endif
+
+/**
+ * Signal/SEH handling
+ * Has to be clean for using with SEH on windows, i.e. no construction of C++ object instances is allowed!
+ * TODO Check for multi-threading issues!
+ *
+ */
+int CppCheckExecutor::check_wrapper(CppCheck& cppcheck, int argc, const char* const argv[])
+{
+#ifdef USE_WINDOWS_SEH
+    __try {
+        return check_internal(cppcheck, argc, argv);
+    } __except (filterException(GetExceptionCode(), GetExceptionInformation())) {
+        // reporting to stdout may not be helpful within a GUI application..
+        fprintf(stderr, "Please report this to the cppcheck developers!\n");
+        return -1;
+    }
+#elif defined(USE_UNIX_SIGNAL_HANDLING)
+    struct sigaction act;
+    memset(&act, 0, sizeof(act));
+    act.sa_flags=SA_SIGINFO;
+    act.sa_sigaction=CppcheckSignalHandler;
+    for (std::size_t s=0; s<GetArrayLength(listofsignals); ++s) {
+        sigaction(listofsignals[s].signalnumber, &act, NULL);
+    }
+    return check_internal(cppcheck, argc, argv);
+#else
+    return check_internal(cppcheck, argc, argv);
+#endif
+}
+
+/*
+ * That is a method which gets called from check_wrapper
+ * */
+int CppCheckExecutor::check_internal(CppCheck& cppcheck, int /*argc*/, const char* const argv[])
+{
+    Settings& settings = cppcheck.settings();
+    _settings = &settings;
     bool std = settings.library.load(argv[0], "std.cfg");
     bool posix = true;
     if (settings.standards.posix)
@@ -200,7 +435,7 @@ int CppCheckExecutor::check(int argc, const char* const argv[])
         for (std::map<std::string, std::size_t>::const_iterator i = _files.begin(); i != _files.end(); ++i) {
             if (!_settings->library.markupFile(i->first)
                 || !_settings->library.processMarkupAfterCode(i->first)) {
-                returnValue += cppCheck.check(i->first);
+                returnValue += cppcheck.check(i->first);
                 processedsize += i->second;
                 if (!settings._errorsOnly)
                     reportStatus(c + 1, _files.size(), processedsize, totalfilesize);
@@ -212,7 +447,7 @@ int CppCheckExecutor::check(int argc, const char* const argv[])
         // c/cpp files have been parsed and checked
         for (std::map<std::string, std::size_t>::const_iterator i = _files.begin(); i != _files.end(); ++i) {
             if (_settings->library.markupFile(i->first) && _settings->library.processMarkupAfterCode(i->first)) {
-                returnValue += cppCheck.check(i->first);
+                returnValue += cppcheck.check(i->first);
                 processedsize += i->second;
                 if (!settings._errorsOnly)
                     reportStatus(c + 1, _files.size(), processedsize, totalfilesize);
@@ -220,7 +455,7 @@ int CppCheckExecutor::check(int argc, const char* const argv[])
             }
         }
 
-        cppCheck.checkFunctionUsage();
+        cppcheck.checkFunctionUsage();
     } else if (!ThreadExecutor::isEnabled()) {
         std::cout << "No thread support yet implemented for this platform." << std::endl;
     } else {
@@ -233,9 +468,9 @@ int CppCheckExecutor::check(int argc, const char* const argv[])
         reportUnmatchedSuppressions(settings.nomsg.getUnmatchedGlobalSuppressions());
 
     if (!settings.checkConfiguration) {
-        cppCheck.tooManyConfigsError("",0U);
+        cppcheck.tooManyConfigsError("",0U);
 
-        if (settings.isEnabled("missingInclude") && Preprocessor::missingIncludeFlag) {
+        if (settings.isEnabled("missingInclude") && (Preprocessor::missingIncludeFlag || Preprocessor::missingSystemIncludeFlag)) {
             const std::list<ErrorLogger::ErrorMessage::FileLocation> callStack;
             ErrorLogger::ErrorMessage msg(callStack,
                                           Severity::information,
@@ -245,7 +480,7 @@ int CppCheckExecutor::check(int argc, const char* const argv[])
                                           "files are found. Please check your project's include directories and add all of them "
                                           "as include directories for Cppcheck. To see what files Cppcheck cannot find use "
                                           "--check-config.",
-                                          "missingInclude",
+                                          Preprocessor::missingIncludeFlag ? "missingInclude" : "missingIncludeSystem",
                                           false);
             reportInfo(msg);
         }
