@@ -20,7 +20,7 @@
 /**
  *
  * @mainpage Cppcheck
- * @version 1.64
+ * @version 1.65
  *
  * @section overview_sec Overview
  * Cppcheck is a simple tool for static analysis of C/C++ code.
@@ -108,6 +108,11 @@ void CheckOther::checkZeroDivision()
  */
 int main(int argc, char* argv[])
 {
+    // MS Visual C++ memory leak debug tracing
+#if defined(_MSC_VER) && defined(_DEBUG)
+    _CrtSetDbgFlag(_CrtSetDbgFlag(_CRTDBG_REPORT_FLAG) | _CRTDBG_LEAK_CHECK_DF);
+#endif
+
     CppCheckExecutor exec;
 #ifdef _WIN32
     char exename[1024] = {0};
