@@ -31,7 +31,11 @@ of the GNU General Public License version 3</source>
     </message>
     <message utf8="true">
         <source>Copyright © 2007-2013 Daniel Marjamäki and cppcheck team.</source>
-        <translation type="unfinished">Copyright © 2007-2012 Daniel Marjamäki and cppcheck team. {2007-2013 ?}</translation>
+        <translation type="obsolete">Copyright © 2007-2012 Daniel Marjamäki and cppcheck team. {2007-2013 ?}</translation>
+    </message>
+    <message utf8="true">
+        <source>Copyright © 2007-2014 Daniel Marjamäki and cppcheck team.</source>
+        <translation type="unfinished">Copyright © 2007-2012 Daniel Marjamäki and cppcheck team. {2007-2013 ?} {2007-2014 ?}</translation>
     </message>
 </context>
 <context>
@@ -643,20 +647,6 @@ Opening a new XML file will clear current results.Do you want to proceed?</sourc
         <source>Select files to check</source>
         <translation type="unfinished">검사할 파일 선택</translation>
     </message>
-    <message>
-        <source>Cppcheck GUI.
-
-Syntax:
-    cppcheck-gui [OPTIONS] [files or paths]
-
-Options:
-    -h, --help     Print this help
-    -p &lt;file&gt;      Open given project file and start checking it
-    -l &lt;file&gt;      Open given results xml file
-    -d &lt;directory&gt; Specify the directory that was checked to generate the results xml specified with -l
-    -v, --version  Show program version</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Cppcheck GUI - Command line parameters</source>
         <translation type="unfinished"></translation>
@@ -690,7 +680,22 @@ Options:
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Failed to load %1. Your Cppcheck installation is broken.</source>
+        <source>Cppcheck GUI.
+
+Syntax:
+    cppcheck-gui [OPTIONS] [files or paths]
+
+Options:
+    -h, --help              Print this help
+    -p &lt;file&gt;               Open given project file and start checking it
+    -l &lt;file&gt;               Open given results xml file
+    -d &lt;directory&gt;          Specify the directory that was checked to generate the results xml specified with -l
+    -v, --version           Show program version
+    --data-dir=&lt;directory&gt;  Specify directory where GUI datafiles are located (translations, cfg)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to load %1. Your Cppcheck installation is broken. You can use --data-dir=&lt;directory&gt; at the command line to specify where this file is located.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
