@@ -46,9 +46,15 @@ ProjectFileDialog::ProjectFileDialog(const QString &path, QWidget *parent)
     // Checkboxes for the libraries..
     const QString applicationFilePath = QCoreApplication::applicationFilePath();
     const QString appPath = QFileInfo(applicationFilePath).canonicalPath();
-    const QString searchPaths[] = { ":/cfg", appPath, appPath + "/cfg", inf.canonicalPath() };
-    for (int i = 0; i < sizeof(searchPaths) / sizeof(searchPaths[0]); i++) {
-        QDir dir(searchPaths[i]);
+    QSettings settings;
+    const QString datadir = settings.value("DATADIR",QString()).toString();
+    QStringList searchPaths;
+    searchPaths << appPath << appPath + "/cfg" << inf.canonicalPath();
+    if (!datadir.isEmpty())
+        searchPaths << datadir << datadir + "/cfg";
+    QStringList libs;
+    foreach(const QString sp, searchPaths) {
+        QDir dir(sp);
         dir.setSorting(QDir::Name);
         dir.setNameFilters(QStringList("*.cfg"));
         dir.setFilter(QDir::Files | QDir::NoDotAndDotDot);
@@ -57,12 +63,17 @@ ProjectFileDialog::ProjectFileDialog(const QString &path, QWidget *parent)
             library.chop(4);
             if (library.compare("std", Qt::CaseInsensitive) == 0)
                 continue;
-            QCheckBox *checkbox = new QCheckBox(this);
-            checkbox->setText(library);
-            mUI.librariesLayout->addWidget(checkbox);
-            mLibraryCheckboxes << checkbox;
+            if (libs.indexOf(library) == -1)
+                libs << library;
         }
     }
+    qSort(libs);
+    foreach(const QString library, libs) {
+        QCheckBox *checkbox = new QCheckBox(this);
+        checkbox->setText(library);
+        mUI.librariesLayout->addWidget(checkbox);
+        mLibraryCheckboxes << checkbox;
+    }
 
     connect(mUI.mButtons, SIGNAL(accepted()), this, SLOT(accept()));
     connect(mUI.mBtnAddInclude, SIGNAL(clicked()), this, SLOT(AddIncludeDir()));
