@@ -89,7 +89,7 @@ void CheckClass::constructors()
             // If there is a private variable, there should be a constructor..
             std::list<Variable>::const_iterator var;
             for (var = scope->varlist.begin(); var != scope->varlist.end(); ++var) {
-                if (var->isPrivate() && !var->isStatic() &&
+                if (var->isPrivate() && !var->isStatic() && !Token::Match(var->nameToken(), "%varid% ; %varid% =", var->declarationId()) &&
                     (!var->isClass() || (var->type() && var->type()->needInitialization == Type::True))) {
                     noConstructorError(scope->classDef, scope->className, scope->classDef->str() == "struct");
                     break;
@@ -432,10 +432,12 @@ bool CheckClass::isBaseClassFunc(const Token *tok, const Scope *scope)
 
 void CheckClass::initializeVarList(const Function &func, std::list<const Function *> &callstack, const Scope *scope, std::vector<Usage> &usage)
 {
+    if (!func.functionScope)
+        throw InternalError(0, "Internal Error: Invalid syntax"); // #5702
     bool initList = func.isConstructor();
     const Token *ftok = func.arg->link()->next();
     int level = 0;
-    for (; ftok != func.functionScope->classEnd; ftok = ftok->next()) {
+    for (; ftok && ftok != func.functionScope->classEnd; ftok = ftok->next()) {
         // Class constructor.. initializing variables like this
         // clKalle::clKalle() : var(value) { }
         if (initList) {
@@ -469,7 +471,34 @@ void CheckClass::initializeVarList(const Function &func, std::list<const Functio
                     }
                 }
             } else if (level == 0 && Token::Match(ftok, "%var% {") && ftok->str() != "const" && Token::Match(ftok->next()->link()->next(), "%type%|,|{")) {
-                initVar(ftok->str(), scope, usage);
+                if (ftok->str() != func.name()) {
+                    initVar(ftok->str(), scope, usage);
+                } else { // c++11 delegate constructor
+                    const Function *member = scope->findFunction(ftok);
+                    // member function found
+                    if (member) {
+                        // recursive call
+                        // assume that all variables are initialized
+                        if (std::find(callstack.begin(), callstack.end(), member) != callstack.end()) {
+                            /** @todo false negative: just bail */
+                            assignAllVar(usage);
+                            return;
+                        }
+
+                        // member function has implementation
+                        if (member->hasBody) {
+                            // initialize variable use list using member function
+                            callstack.push_back(member);
+                            initializeVarList(*member, callstack, scope, usage);
+                            callstack.pop_back();
+                        }
+
+                        // there is a called member function, but it has no implementation, so we assume it initializes everything
+                        else {
+                            assignAllVar(usage);
+                        }
+                    }
+                }
                 ftok = ftok->linkAt(1);
             } else if (level != 0 && Token::Match(ftok, "%var% =")) // assignment in the initializer: var(value = x)
                 assignVar(ftok->str(), scope, usage);
@@ -550,7 +579,7 @@ void CheckClass::initializeVarList(const Function &func, std::list<const Functio
             ftok = ftok->tokAt(2);
 
         // Skip "classname :: "
-        if (Token::Match(ftok, ":: %var% "))
+        if (Token::Match(ftok, ":: %var%"))
             ftok = ftok->next();
         while (Token::Match(ftok, "%var% ::"))
             ftok = ftok->tokAt(2);
@@ -765,6 +794,9 @@ void CheckClass::initializationListUsage()
                                 tok2->strAt(-1)!=".") { // Is there a dependency between two member variables?
                                 allowed = false;
                                 break;
+                            } else if (var2 && (var2->isArray() && var2->isLocal())) { // Can't initialize with a local array
+                                allowed = false;
+                                break;
                             }
                         } else if (tok2->str() == "this") { // 'this' instance is not completely constructed in initialization list
                             allowed = false;
@@ -846,7 +878,7 @@ void CheckClass::privateFunctions()
         std::list<const Function*> FuncList;
         for (std::list<Function>::const_iterator func = scope->functionList.begin(); func != scope->functionList.end(); ++func) {
             // Get private functions..
-            if (func->type == Function::eFunction && func->access == Private)
+            if (func->type == Function::eFunction && func->access == Private && !func->isOperator) // TODO: There are smarter ways to check private operator usage
                 FuncList.push_back(&*func);
         }
 
@@ -942,7 +974,7 @@ void CheckClass::checkMemset()
                     if (var && arg1->strAt(1) == ",") {
                         if (var->isPointer()) {
                             derefs--;
-                            if (var->typeEndToken() && Token::Match(var->typeEndToken()->previous(), "* *")) // Check if it's a pointer to pointer
+                            if (var->typeEndToken() && Token::simpleMatch(var->typeEndToken()->previous(), "* *")) // Check if it's a pointer to pointer
                                 derefs--;
                         }
 
@@ -981,10 +1013,13 @@ void CheckClass::checkMemset()
                         type = t->classScope;
                 }
 
-                if (type)
-                    checkMemsetType(&(*scope), tok, type, false);
+                if (type) {
+                    std::list<const Scope *> parsedTypes;
+                    checkMemsetType(&(*scope), tok, type, false, parsedTypes);
+                }
             } else if (tok->variable() && tok->variable()->typeScope() && Token::Match(tok, "%var% = calloc|malloc|realloc|g_malloc|g_try_malloc|g_realloc|g_try_realloc (")) {
-                checkMemsetType(&(*scope), tok->tokAt(2), tok->variable()->typeScope(), true);
+                std::list<const Scope *> parsedTypes;
+                checkMemsetType(&(*scope), tok->tokAt(2), tok->variable()->typeScope(), true, parsedTypes);
 
                 if (tok->variable()->typeScope()->numConstructors > 0 && _settings->isEnabled("warning"))
                     mallocOnClassWarning(tok, tok->strAt(2), tok->variable()->typeScope()->classDef);
@@ -993,12 +1028,17 @@ void CheckClass::checkMemset()
     }
 }
 
-void CheckClass::checkMemsetType(const Scope *start, const Token *tok, const Scope *type, bool allocation)
+void CheckClass::checkMemsetType(const Scope *start, const Token *tok, const Scope *type, bool allocation, std::list<const Scope *> parsedTypes)
 {
+    // If type has been checked there is no need to check it again
+    if (std::find(parsedTypes.begin(), parsedTypes.end(), type) != parsedTypes.end())
+        return;
+    parsedTypes.push_back(type);
+
     // recursively check all parent classes
     for (std::size_t i = 0; i < type->definedType->derivedFrom.size(); i++) {
         if (type->definedType->derivedFrom[i].type && type->definedType->derivedFrom[i].type->classScope)
-            checkMemsetType(start, tok, type->definedType->derivedFrom[i].type->classScope, allocation);
+            checkMemsetType(start, tok, type->definedType->derivedFrom[i].type->classScope, allocation, parsedTypes);
     }
 
     // Warn if type is a class that contains any virtual functions
@@ -1017,20 +1057,25 @@ void CheckClass::checkMemsetType(const Scope *start, const Token *tok, const Sco
     std::list<Variable>::const_iterator var;
 
     for (var = type->varlist.begin(); var != type->varlist.end(); ++var) {
+        if (var->isReference()) {
+            memsetErrorReference(tok, tok->str(), type->classDef->str());
+            continue;
+        }
         // don't warn if variable static or const, pointer or reference
-        if (!var->isStatic() && !var->isConst() && !var->isPointer() && !var->isReference()) {
+        if (!var->isStatic() && !var->isConst() && !var->isPointer()) {
             const Token *tok1 = var->typeStartToken();
+            const Scope *typeScope = var->typeScope();
 
             // check for std:: type
-            if (var->isStlType())
+            if (var->isStlType() && tok1->strAt(2) != "array")
                 if (allocation)
                     mallocOnClassError(tok, tok->str(), type->classDef, "'std::" + tok1->strAt(2) + "'");
                 else
                     memsetError(tok, tok->str(), "'std::" + tok1->strAt(2) + "'", type->classDef->str());
 
             // check for known type
-            else if (var->typeScope())
-                checkMemsetType(start, tok, var->typeScope(), allocation);
+            else if (typeScope && typeScope != type)
+                checkMemsetType(start, tok, typeScope, allocation, parsedTypes);
         }
     }
 }
@@ -1059,9 +1104,19 @@ void CheckClass::mallocOnClassError(const Token* tok, const std::string &memfunc
 
 void CheckClass::memsetError(const Token *tok, const std::string &memfunc, const std::string &classname, const std::string &type)
 {
-    reportError(tok, Severity::error, "memsetClass", "Using '" + memfunc + "' on " + type + " that contains a " + classname + ".");
+    reportError(tok, Severity::error, "memsetClass",
+                "Using '" + memfunc + "' on " + type + " that contains a " + classname + ".\n"
+                "Using '" + memfunc + "' on " + type + " that contains a " + classname + " is unsafe, because constructor, destructor "
+                "and copy operator calls are omitted. These are necessary for this non-POD type to ensure that a valid object "
+                "is created.");
 }
 
+void CheckClass::memsetErrorReference(const Token *tok, const std::string &memfunc, const std::string &type)
+{
+    reportError(tok, Severity::error, "memsetClass", "Using '" + memfunc + "' on " + type + " that contains a reference.");
+}
+
+
 //---------------------------------------------------------------------------
 // ClassCheck: "void operator=(" and "const type & operator=("
 //---------------------------------------------------------------------------
@@ -1096,7 +1151,9 @@ void CheckClass::operatorEq()
 
 void CheckClass::operatorEqReturnError(const Token *tok, const std::string &className)
 {
-    reportError(tok, Severity::style, "operatorEq", "'" + className + "::operator=' should return '" + className + " &'.");
+    reportError(tok, Severity::style, "operatorEq", "'" + className + "::operator=' should return '" + className + " &'.\n"
+                "The "+className+"::operator= does not conform to standard C/C++ behaviour. To conform to standard C/C++ behaviour, return a reference to self (such as: '"+className+" &"+className+"::operator=(..) { .. return *this; }'. For safety reasons it might be better to not fix this message. If you think that safety is always more important than conformance then please ignore/suppress this message. For more details about this topic, see the book \"Effective C++\" by Scott Meyers."
+               );
 }
 
 //---------------------------------------------------------------------------
@@ -1238,7 +1295,7 @@ void CheckClass::operatorEqToSelf()
     }
 }
 
-bool CheckClass::hasAllocation(const Function *func, const Scope* scope)
+bool CheckClass::hasAllocation(const Function *func, const Scope* scope) const
 {
     // This function is called when no simple check was found for assignment
     // to self.  We are currently looking for:
@@ -1545,7 +1602,7 @@ void CheckClass::checkConst()
     }
 }
 
-bool CheckClass::isMemberVar(const Scope *scope, const Token *tok)
+bool CheckClass::isMemberVar(const Scope *scope, const Token *tok) const
 {
     bool again = false;
 
@@ -1580,7 +1637,7 @@ bool CheckClass::isMemberVar(const Scope *scope, const Token *tok)
     }
 
     // not found in this class
-    if (!scope->definedType->derivedFrom.empty()) {
+    if (!scope->definedType->derivedFrom.empty() && !scope->definedType->hasCircularDependencies()) {
         // check each base class
         for (unsigned int i = 0; i < scope->definedType->derivedFrom.size(); ++i) {
             // find the base class
@@ -1633,7 +1690,7 @@ static unsigned int countMinArgs(const Token* argList)
     return count;
 }
 
-bool CheckClass::isMemberFunc(const Scope *scope, const Token *tok)
+bool CheckClass::isMemberFunc(const Scope *scope, const Token *tok) const
 {
     unsigned int args = countParameters(tok);
 
@@ -1653,7 +1710,7 @@ bool CheckClass::isMemberFunc(const Scope *scope, const Token *tok)
             const Type *derivedFrom = scope->definedType->derivedFrom[i].type;
 
             // find the function in the base class
-            if (derivedFrom && derivedFrom->classScope) {
+            if (derivedFrom && derivedFrom->classScope && !derivedFrom->hasCircularDependencies()) {
                 if (isMemberFunc(derivedFrom->classScope, tok))
                     return true;
             }
@@ -1663,7 +1720,7 @@ bool CheckClass::isMemberFunc(const Scope *scope, const Token *tok)
     return false;
 }
 
-bool CheckClass::isConstMemberFunc(const Scope *scope, const Token *tok)
+bool CheckClass::isConstMemberFunc(const Scope *scope, const Token *tok) const
 {
     unsigned int args = countParameters(tok);
 
@@ -1693,7 +1750,7 @@ bool CheckClass::isConstMemberFunc(const Scope *scope, const Token *tok)
             const Type *derivedFrom = scope->definedType->derivedFrom[i].type;
 
             // find the function in the base class
-            if (derivedFrom && derivedFrom->classScope) {
+            if (derivedFrom && derivedFrom->classScope && !derivedFrom->hasCircularDependencies()) {
                 if (isConstMemberFunc(derivedFrom->classScope, tok))
                     return true;
             }
@@ -1703,7 +1760,7 @@ bool CheckClass::isConstMemberFunc(const Scope *scope, const Token *tok)
     return false;
 }
 
-bool CheckClass::checkConstFunc(const Scope *scope, const Function *func, bool& memberAccessed)
+bool CheckClass::checkConstFunc(const Scope *scope, const Function *func, bool& memberAccessed) const
 {
     // if the function doesn't have any assignment nor function call,
     // it can be a const function..
@@ -1728,8 +1785,12 @@ bool CheckClass::checkConstFunc(const Scope *scope, const Function *func, bool&
                 } else if (end->strAt(1) == "[") {
                     if (end->varId()) {
                         const Variable *var = end->variable();
-
-                        if (var && Token::simpleMatch(var->typeStartToken(), "std :: map")) // operator[] changes a map
+                        // The container contains the STL types whose operator[] is not a const.
+                        // THIS ARRAY MUST BE ORDERED ALPHABETICALLY
+                        static const char* const stl_containers [] = {
+                            "map", "unordered_map"
+                        };
+                        if (var && var->isStlType(stl_containers))
                             return false;
                     }
                     if (!jumpBackToken)
