@@ -61,6 +61,8 @@ public:
         checkExceptionSafety.deallocThrow();
         checkExceptionSafety.checkRethrowCopy();
         checkExceptionSafety.checkCatchExceptionByValue();
+        checkExceptionSafety.nothrowThrows();
+        checkExceptionSafety.unhandledExceptionSpecification();
     }
 
     /** Don't throw exceptions in destructors */
@@ -75,6 +77,12 @@ public:
     /** @brief %Check for exceptions that are caught by value instead of by reference */
     void checkCatchExceptionByValue();
 
+    /** @brief %Check for functions that throw that shouldn't */
+    void nothrowThrows();
+
+    /** @brief %Check for unhandled exception specification */
+    void unhandledExceptionSpecification();
+
 private:
     /** Don't throw exceptions in destructors */
     void destructorsError(const Token * const tok) {
@@ -100,6 +108,38 @@ private:
                     "as a (const) reference which is usually recommended in C++.");
     }
 
+    /** Don't throw exceptions in noexcept functions */
+    void noexceptThrowError(const Token * const tok) {
+        reportError(tok, Severity::error, "exceptThrowInNoexecptFunction", "Exception thrown in noexcept function.");
+    }
+
+    /** Don't throw exceptions in throw() functions */
+    void nothrowThrowError(const Token * const tok) {
+        reportError(tok, Severity::error, "exceptThrowInNoThrowFunction", "Exception thrown in throw() function.");
+    }
+
+    /** Don't throw exceptions in __attribute__((nothrow))  functions */
+    void nothrowAttributeThrowError(const Token * const tok) {
+        reportError(tok, Severity::error, "exceptThrowInAttributeNoThrowFunction", "Exception thrown in __attribute__((nothrow)) function.");
+    }
+
+    /** Don't throw exceptions in __declspec(nothrow)  functions */
+    void nothrowDeclspecThrowError(const Token * const tok) {
+        reportError(tok, Severity::error, "exceptThrowInDeclspecNoThrowFunction", "Exception thrown in __declspec(nothrow) function.");
+    }
+
+    /** Missing exception specification */
+    void unhandledExceptionSpecificationError(const Token * const tok1, const Token * const tok2, const std::string & funcname) {
+        std::string str1(tok1 ? tok1->str() : "foo");
+        std::list<const Token*> locationList;
+        locationList.push_back(tok1);
+        locationList.push_back(tok2);
+        reportError(locationList, Severity::style, "unhandledExceptionSpecification",
+                    "Unhandled exception specification when calling function " + str1 + "().\n"
+                    "Unhandled exception specification when calling function " + str1 + "(). "
+                    "Either use a try/catch around the function call, or add a exception specification for " + funcname + "() also.", true);
+    }
+
     /** Generate all possible errors (for --errorlist) */
     void getErrorMessages(ErrorLogger *errorLogger, const Settings *settings) const {
         CheckExceptionSafety c(0, settings, errorLogger);
@@ -107,6 +147,11 @@ private:
         c.deallocThrowError(0, "p");
         c.rethrowCopyError(0, "varname");
         c.catchExceptionByValueError(0);
+        c.noexceptThrowError(0);
+        c.nothrowThrowError(0);
+        c.nothrowAttributeThrowError(0);
+        c.nothrowDeclspecThrowError(0);
+        c.unhandledExceptionSpecificationError(0, 0, "funcname");
     }
 
     /** Short description of class (for --doc) */
@@ -120,7 +165,12 @@ private:
                "* Throwing exceptions in destructors\n"
                "* Throwing exception during invalid state\n"
                "* Throwing a copy of a caught exception instead of rethrowing the original exception\n"
-               "* Exception caught by value instead of by reference\n";
+               "* Exception caught by value instead of by reference\n"
+               "* Throwing exception in noexcept function\n"
+               "* Throwing exception in nothrow() function\n"
+               "* Throwing exception in __attribute__((nothrow)) function\n"
+               "* Throwing exception in __declspec(nothrow) function\n"
+               "* Unhandled exception specification when calling function foo()\n";
     }
 };
 /// @}
