@@ -100,6 +100,7 @@ private:
     void readWriteOnlyFileError(const Token *tok);
     void writeReadOnlyFileError(const Token *tok);
     void useClosedFileError(const Token *tok);
+    void seekOnAppendedFileError(const Token *tok);
     void invalidScanfError(const Token *tok, bool portability);
     void wrongPrintfScanfArgumentsError(const Token* tok,
                                         const std::string &function,
@@ -119,7 +120,7 @@ private:
     void invalidPrintfArgTypeError_float(const Token* tok, unsigned int numFormat, const std::string& specifier, const ArgumentInfo* argInfo);
     void invalidLengthModifierError(const Token* tok, unsigned int numFormat, const std::string& modifier);
     void invalidScanfFormatWidthError(const Token* tok, unsigned int numFormat, int width, const Variable *var);
-    void argumentType(std::ostream & s, const ArgumentInfo * argInfo);
+    static void argumentType(std::ostream & s, const ArgumentInfo * argInfo);
 
     void getErrorMessages(ErrorLogger *errorLogger, const Settings *settings) const {
         CheckIO c(0, settings, errorLogger);
@@ -130,6 +131,7 @@ private:
         c.readWriteOnlyFileError(0);
         c.writeReadOnlyFileError(0);
         c.useClosedFileError(0);
+        c.seekOnAppendedFileError(0);
         c.invalidScanfError(0, false);
         c.wrongPrintfScanfArgumentsError(0,"printf",3,2);
         c.invalidScanfArgTypeError_s(0, 1, "s", NULL);
@@ -157,6 +159,7 @@ private:
                "* Use a file that has been closed\n"
                "* File input/output without positioning results in undefined behaviour\n"
                "* Read to a file that has only been opened for writing (or vice versa)\n"
+               "* Repositioning operation on a file opened in append mode\n"
                "* Using fflush() on an input stream\n"
                "* Invalid usage of output stream. For example: 'std::cout << std::cout;'\n"
                "* Wrong number of arguments given to 'printf' or 'scanf;'\n";
