@@ -232,7 +232,7 @@ void CheckLeakAutoVar::checkScope(const Token * const startToken,
 
             // allocation?
             if (Token::Match(tok->tokAt(2), "%type% (")) {
-                int i = _settings->library.alloc(tok->strAt(2));
+                int i = _settings->library.alloc(tok->tokAt(2));
                 if (i > 0) {
                     alloctype[tok->varId()] = i;
                 }
@@ -255,7 +255,7 @@ void CheckLeakAutoVar::checkScope(const Token * const startToken,
                 if (innerTok->str() == ")")
                     break;
                 if (innerTok->str() == "(" && innerTok->previous()->isName()) {
-                    const int deallocId = _settings->library.dealloc(tok->str());
+                    const int deallocId = _settings->library.dealloc(tok);
                     functionCall(innerTok->previous(), varInfo, deallocId);
                     innerTok = innerTok->link();
                 }
@@ -263,8 +263,8 @@ void CheckLeakAutoVar::checkScope(const Token * const startToken,
 
             const Token *tok2 = tok->linkAt(1);
             if (Token::simpleMatch(tok2, ") {")) {
-                VarInfo varInfo1(*varInfo);
-                VarInfo varInfo2(*varInfo);
+                VarInfo varInfo1(*varInfo);  // VarInfo for if code
+                VarInfo varInfo2(*varInfo);  // VarInfo for else code
 
                 if (Token::Match(tok->next(), "( %var% )")) {
                     varInfo2.erase(tok->tokAt(2)->varId());
@@ -274,6 +274,14 @@ void CheckLeakAutoVar::checkScope(const Token * const startToken,
                     varInfo1.erase(tok->tokAt(3)->varId());
                 } else if (Token::Match(tok->next(), "( %var% ( ! %var% ) )|&&")) {
                     varInfo1.erase(tok->tokAt(5)->varId());
+                } else if (Token::Match(tok->next(), "( %var% < 0 )|&&")) {
+                    varInfo1.erase(tok->tokAt(2)->varId());
+                } else if (Token::Match(tok->next(), "( 0 > %var% )|&&")) {
+                    varInfo1.erase(tok->tokAt(4)->varId());
+                } else if (Token::Match(tok->next(), "( %var% > 0 )|&&")) {
+                    varInfo2.erase(tok->tokAt(2)->varId());
+                } else if (Token::Match(tok->next(), "( 0 < %var% )|&&")) {
+                    varInfo2.erase(tok->tokAt(4)->varId());
                 }
 
                 checkScope(tok2->next(), &varInfo1, notzero);
@@ -335,7 +343,7 @@ void CheckLeakAutoVar::checkScope(const Token * const startToken,
 
         // Function call..
         else if (Token::Match(tok, "%type% (") && tok->str() != "return") {
-            const int dealloc = _settings->library.dealloc(tok->str());
+            const int dealloc = _settings->library.dealloc(tok);
 
             functionCall(tok, varInfo, dealloc);
 
@@ -345,15 +353,12 @@ void CheckLeakAutoVar::checkScope(const Token * const startToken,
             if (dealloc == NOALLOC && Token::simpleMatch(tok, ") ; }")) {
                 const std::string &functionName(tok->link()->previous()->str());
                 bool unknown = false;
-                if (_settings->library.leakignore.find(functionName) == _settings->library.leakignore.end() &&
-                    _settings->library.use.find(functionName) == _settings->library.use.end() &&
-                    _tokenizer->IsScopeNoReturn(tok->tokAt(2), &unknown)) {
-                    if (unknown) {
-                        //const std::string &functionName(tok->link()->previous()->str());
-                        varInfo->possibleUsageAll(functionName);
-                    } else {
+                if (_tokenizer->IsScopeNoReturn(tok->tokAt(2), &unknown)) {
+                    if (!unknown)
                         varInfo->clear();
-                    }
+                    else if (_settings->library.leakignore.find(functionName) == _settings->library.leakignore.end() &&
+                             _settings->library.use.find(functionName) == _settings->library.use.end())
+                        varInfo->possibleUsageAll(functionName);
                 }
             }
 
