@@ -30,6 +30,10 @@ class Token;
 class Function;
 class Variable;
 
+/** Is expressions same? */
+bool isSameExpression(const Token *tok1, const Token *tok2, const std::set<std::string> &constFunctions);
+
+
 /// @addtogroup Checks
 /// @{
 
@@ -61,7 +65,6 @@ public:
         checkOther.checkRedundantAssignmentInSwitch();
         checkOther.checkSuspiciousCaseInSwitch();
         checkOther.checkSelfAssignment();
-        checkOther.checkDuplicateIf();
         checkOther.checkDuplicateBranch();
         checkOther.checkDuplicateExpression();
         checkOther.checkUnreachableCode();
@@ -263,7 +266,7 @@ public:
     void checkCastIntToCharAndBack();
 
     /** @brief %Check for using of comparison functions evaluating always to true or false. */
-    void checkComparisonFunctionIsAlwaysTrueOrFalse(void);
+    void checkComparisonFunctionIsAlwaysTrueOrFalse();
 
 private:
     bool isUnsigned(const Variable *var) const;
@@ -273,7 +276,7 @@ private:
     void checkComparisonFunctionIsAlwaysTrueOrFalseError(const Token* tok, const std::string &strFunctionName, const std::string &varName, const bool result);
     void checkCastIntToCharAndBackError(const Token *tok, const std::string &strFunctionName);
     void checkPipeParameterSizeError(const Token *tok, const std::string &strVarName, const std::string &strDim);
-    void oppositeInnerConditionError(const Token *tok);
+    void oppositeInnerConditionError(const Token *tok1, const Token* tok2);
     void clarifyCalculationError(const Token *tok, const std::string &op);
     void clarifyConditionError(const Token *tok, bool assign, bool boolop);
     void clarifyStatementError(const Token* tok);
@@ -290,8 +293,8 @@ private:
     void charBitOpError(const Token *tok);
     void variableScopeError(const Token *tok, const std::string &varname);
     void strPlusCharError(const Token *tok);
-    void zerodivError(const Token *tok);
-    void zerodivcondError(const Token *tokcond, const Token *tokdiv);
+    void zerodivError(const Token *tok, bool inconclusive);
+    void zerodivcondError(const Token *tokcond, const Token *tokdiv, bool inconclusive);
     void nanInArithmeticExpressionError(const Token *tok);
     void mathfunctionCallError(const Token *tok, const unsigned int numParam = 1);
     void redundantAssignmentError(const Token *tok1, const Token* tok2, const std::string& var, bool inconclusive);
@@ -340,8 +343,8 @@ private:
         c.invalidFunctionArgError(0, "func_name", 1, "1-4");
         c.invalidFunctionArgBoolError(0, "func_name", 1);
         c.udivError(0, false);
-        c.zerodivError(0);
-        c.zerodivcondError(0,0);
+        c.zerodivError(0, false);
+        c.zerodivcondError(0,0,false);
         c.mathfunctionCallError(0);
         c.misusedScopeObjectError(NULL, "varname");
         c.doubleFreeError(0, "varname");
@@ -357,7 +360,7 @@ private:
         // style/warning
         c.checkComparisonFunctionIsAlwaysTrueOrFalseError(0,"isless","varName",false);
         c.checkCastIntToCharAndBackError(0,"func_name");
-        c.oppositeInnerConditionError(0);
+        c.oppositeInnerConditionError(0, 0);
         c.cstyleCastError(0);
         c.passedByValueError(0, "parametername");
         c.constStatementError(0, "type");
@@ -372,7 +375,7 @@ private:
         c.suspiciousEqualityComparisonError(0);
         c.selfAssignmentError(0, "varname");
         c.incorrectLogicOperatorError(0, "foo > 3 && foo < 4", true);
-        c.redundantConditionError(0, "If x > 10 the condition x > 11 is always true.");
+        c.redundantConditionError(0, "If x > 11 the condition x > 10 is always true.");
         c.memsetZeroBytesError(0, "varname");
         c.memsetFloatError(0, "varname");
         c.memsetValueOutOfRangeError(0, "varname");
@@ -382,7 +385,6 @@ private:
         c.incorrectStringCompareError(0, "substr", "\"Hello World\"");
         c.suspiciousStringCompareError(0, "foo");
         c.incorrectStringBooleanError(0, "\"Hello World\"");
-        c.duplicateIfError(0, 0);
         c.duplicateBranchError(0, 0);
         c.duplicateExpressionError(0, 0, "&&");
         c.alwaysTrueFalseStringCompareError(0, "str1", "str2");
