@@ -1,5 +1,5 @@
-#ifndef CONFIG_H
-#define CONFIG_H
+#ifndef configH
+#define configH
 
 #ifdef _WIN32
 #  ifdef CPPCHECKLIB_EXPORT
@@ -13,4 +13,10 @@
 #  define CPPCHECKLIB
 #endif
 
+// MS Visual C++ memory leak debug tracing
+#if defined(_MSC_VER) && defined(_DEBUG)
+#  define _CRTDBG_MAP_ALLOC
+#  include <crtdbg.h>
 #endif
+
+#endif // configH
