@@ -21,14 +21,59 @@
 #include "mathlib.h"
 #include "errorlogger.h"
 
-#include <string>
-#include <sstream>
-#include <cstdlib>
 #include <cmath>
 #include <cctype>
 #include <limits>
 
-MathLib::bigint MathLib::toLongNumber(const std::string &str)
+MathLib::biguint MathLib::toULongNumber(const std::string & str)
+{
+    // hexadecimal numbers:
+    if (isHex(str)) {
+        if (str[0] == '-') {
+            biguint ret = 0;
+            std::istringstream istr(str);
+            istr >> std::hex >> ret;
+            return ret;
+        } else {
+            unsigned long long ret = 0;
+            std::istringstream istr(str);
+            istr >> std::hex >> ret;
+            return (biguint)ret;
+        }
+    }
+
+    // octal numbers:
+    if (isOct(str)) {
+        biguint ret = 0;
+        std::istringstream istr(str);
+        istr >> std::oct >> ret;
+        return ret;
+    }
+
+    // binary numbers:
+    if (isBin(str)) {
+        biguint ret = 0;
+        for (std::string::size_type i = str[0] == '0'?2:3; i < str.length(); i++) {
+            ret <<= 1;
+            if (str[i] == '1')
+                ret |= 1;
+        }
+        /* if (str[0] == '-')
+                ret = -ret; */
+        return ret;
+    }
+
+    if (isFloat(str)) {
+        return static_cast<biguint>(std::atof(str.c_str()));
+    }
+
+    biguint ret = 0;
+    std::istringstream istr(str);
+    istr >> ret;
+    return ret;
+}
+
+MathLib::bigint MathLib::toLongNumber(const std::string & str)
 {
     // hexadecimal numbers:
     if (isHex(str)) {
@@ -66,8 +111,9 @@ MathLib::bigint MathLib::toLongNumber(const std::string &str)
         return ret;
     }
 
-    if (isFloat(str))
+    if (isFloat(str)) {
         return static_cast<bigint>(std::atof(str.c_str()));
+    }
 
     bigint ret = 0;
     std::istringstream istr(str);
@@ -75,6 +121,7 @@ MathLib::bigint MathLib::toLongNumber(const std::string &str)
     return ret;
 }
 
+
 double MathLib::toDoubleNumber(const std::string &str)
 {
     if (isHex(str))
@@ -105,7 +152,9 @@ bool MathLib::isFloat(const std::string &s)
 {
     if (s.empty())
         return false;
-    enum {START, BASE_PLUSMINUS, BASE_DIGITS1, LEADING_DECIMAL, TRAILING_DECIMAL, BASE_DIGITS2, E, MANTISSA_PLUSMINUS, MANTISSA_DIGITS, F} state = START;
+    enum State {
+        START, BASE_PLUSMINUS, BASE_DIGITS1, LEADING_DECIMAL, TRAILING_DECIMAL, BASE_DIGITS2, E, MANTISSA_PLUSMINUS, MANTISSA_DIGITS, F
+    } state = START;
     for (std::string::const_iterator it = s.begin(); it != s.end(); ++it) {
         switch (state) {
         case START:
@@ -184,7 +233,7 @@ bool MathLib::isFloat(const std::string &s)
             return false;
         }
     }
-    return (state==BASE_DIGITS2 || state == MANTISSA_DIGITS || state == TRAILING_DECIMAL || state == F);
+    return (state==BASE_DIGITS2 || state==MANTISSA_DIGITS || state==TRAILING_DECIMAL || state==F);
 }
 
 bool MathLib::isNegative(const std::string &s)
@@ -202,94 +251,239 @@ bool MathLib::isPositive(const std::string &s)
     return !MathLib::isNegative(s);
 }
 
-bool MathLib::isOct(const std::string& str)
+/*! \brief Does the string represent an octal number?
+ * In case leading or trailing white space is provided, the function
+ * returns false.
+ * Additional information can be found here:
+ * http://gcc.gnu.org/onlinedocs/gcc/Binary-constants.html
+ *
+ * \param[in] s The string to check. In case the string is empty, the function returns false.
+ * \return Return true in case a octal number is provided and false otherwise.
+ **/
+bool MathLib::isOct(const std::string& s)
 {
-    const bool sign = str[0]=='-' || str[0]=='+';
-    return (str[sign?1:0] == '0' && (str.size() == 1 || isOctalDigit(str[sign?2:1])) && !isFloat(str));
+    enum Status {
+        START, PLUSMINUS, OCTAL_PREFIX, DIGITS
+    } state = START;
+    for (std::string::const_iterator it = s.begin(); it != s.end(); ++it) {
+        switch (state) {
+        case START:
+            if (*it == '+' || *it == '-')
+                state = PLUSMINUS;
+            else if (*it == '0')
+                state = OCTAL_PREFIX;
+            else
+                return false;
+            break;
+        case PLUSMINUS:
+            if (*it == '0')
+                state = OCTAL_PREFIX;
+            else
+                return false;
+            break;
+        case OCTAL_PREFIX:
+            if (isOctalDigit(*it))
+                state = DIGITS;
+            else
+                return false;
+            break;
+        case DIGITS:
+            if (isOctalDigit(*it))
+                state = DIGITS;
+            else
+                return isValidSuffix(it,s.end());
+            break;
+        }
+    }
+    return state == DIGITS;
 }
 
-bool MathLib::isHex(const std::string& str)
+bool MathLib::isHex(const std::string& s)
 {
-    const bool sign = str[0]=='-' || str[0]=='+';
-    return (str.compare(sign?1:0, 2, "0x") == 0 || str.compare(sign?1:0, 2, "0X") == 0);
+    enum Status {
+        START, PLUSMINUS, HEX_PREFIX, DIGIT, DIGITS
+    } state = START;
+    for (std::string::const_iterator it = s.begin(); it != s.end(); ++it) {
+        switch (state) {
+        case START:
+            if (*it == '+' || *it == '-')
+                state = PLUSMINUS;
+            else if (*it == '0')
+                state = HEX_PREFIX;
+            else
+                return false;
+            break;
+        case PLUSMINUS:
+            if (*it == '0')
+                state = HEX_PREFIX;
+            else
+                return false;
+            break;
+        case HEX_PREFIX:
+            if (*it == 'x' || *it == 'X')
+                state = DIGIT;
+            else
+                return false;
+            break;
+        case DIGIT:
+            if (isxdigit(*it))
+                state = DIGITS;
+            else
+                return false;
+            break;
+        case DIGITS:
+            if (isxdigit(*it))
+                state = DIGITS;
+            else
+                return isValidSuffix(it,s.end());
+            break;
+        }
+    }
+    return state == DIGITS;
 }
 
-bool MathLib::isBin(const std::string& str)
+bool MathLib::isValidSuffix(std::string::const_iterator it, std::string::const_iterator end)
 {
-    const bool sign = str[0]=='-' || str[0]=='+';
-    return ((str.compare(sign?1:0, 2, "0b") == 0 || str.compare(sign?1:0, 2, "0B") == 0) && str.find_first_not_of("10bB", 1) == std::string::npos);
+    enum Status {
+        START, SUFFIX_U, SUFFIX_UL, SUFFIX_ULL, SUFFIX_L, SUFFIX_LU, SUFFIX_LL, SUFFIX_LLU
+    } state = START;
+    for (; it != end; ++it) {
+        switch (state) {
+        case START:
+            if (*it == 'u' || *it == 'U')
+                state = SUFFIX_U;
+            else if (*it == 'l' || *it == 'L')
+                state = SUFFIX_L;
+            else
+                return false;
+            break;
+        case SUFFIX_U:
+            if (*it == 'l' || *it == 'L')
+                state = SUFFIX_UL; // UL
+            else
+                return false;
+            break;
+        case SUFFIX_UL:
+            if (*it == 'l' || *it == 'L')
+                state = SUFFIX_ULL; // ULL
+            else
+                return false;
+            break;
+        case SUFFIX_L:
+            if (*it == 'u' || *it == 'U')
+                state = SUFFIX_LU; // LU
+            else if (*it == 'l' || *it == 'L')
+                state = SUFFIX_LL; // LL
+            else
+                return false;
+            break;
+        case SUFFIX_LU:
+            return false;
+        case SUFFIX_LL:
+            if (*it == 'u' || *it == 'U')
+                state = SUFFIX_LLU; // LLU
+            else
+                return false;
+            break;
+        default:
+            return false;
+        }
+    }
+    return (state == SUFFIX_U)  || (state == SUFFIX_L)
+           || (state == SUFFIX_UL) || (state == SUFFIX_LU)   || (state == SUFFIX_LL)
+           || (state == SUFFIX_ULL) || (state == SUFFIX_LLU);
+}
+
+/*! \brief Does the string represent a binary number?
+ * In case leading or trailing white space is provided, the function
+ * returns false.
+ * Additional information can be found here:
+ * http://gcc.gnu.org/onlinedocs/gcc/Binary-constants.html
+ *
+ * \param[in] s The string to check. In case the string is empty, the function returns false.
+ * \return Return true in case a binary number is provided and false otherwise.
+ **/
+bool MathLib::isBin(const std::string& s)
+{
+    enum Status {
+        START, PLUSMINUS, GNU_BIN_PREFIX, DIGIT, DIGITS
+    } state = START;
+    for (std::string::const_iterator it = s.begin(); it != s.end(); ++it) {
+        switch (state) {
+        case START:
+            if (*it == '+' || *it == '-')
+                state = PLUSMINUS;
+            else if (*it == '0')
+                state = GNU_BIN_PREFIX;
+            else
+                return false;
+            break;
+        case PLUSMINUS:
+            if (*it == '0')
+                state = GNU_BIN_PREFIX;
+            else
+                return false;
+            break;
+        case GNU_BIN_PREFIX:
+            if (*it == 'b' || *it == 'B')
+                state = DIGIT;
+            else
+                return false;
+            break;
+        case DIGIT:
+            if (*it == '0' || *it == '1')
+                state = DIGITS;
+            else
+                return false;
+            break;
+        case DIGITS:
+            if (*it == '0' || *it == '1')
+                state = DIGITS;
+            else
+                return isValidSuffix(it,s.end());
+            break;
+        }
+    }
+    return state == DIGITS;
+}
+
+bool MathLib::isDec(const std::string & s)
+{
+    enum Status {
+        START, PLUSMINUS, DIGIT, SUFFIX
+    } state = START;
+    for (std::string::const_iterator it = s.begin(); it != s.end(); ++it) {
+        switch (state) {
+        case START:
+            if (*it == '+' || *it == '-')
+                state = PLUSMINUS;
+            else if (isdigit(*it))
+                state = DIGIT;
+            else
+                return false;
+            break;
+        case PLUSMINUS:
+            if (isdigit(*it))
+                state = DIGIT;
+            else
+                return false;
+            break;
+        case DIGIT:
+            if (isdigit(*it))
+                state = DIGIT;
+            else
+                return isValidSuffix(it,s.end());
+            break;
+        case SUFFIX:
+            break;
+        }
+    }
+    return state == DIGIT;
 }
 
 bool MathLib::isInt(const std::string & s)
 {
-    // perform prechecks:
-    // ------------------
-    // first check, if a point is found, it is an floating point value
-    const std::string charsToIndicateAFloat=".eE";
-    if (s.find_last_of(charsToIndicateAFloat) != std::string::npos)
-        return false;
-
-    // prechecking has nothing found,...
-    // gather information
-    enum Representation {
-        eOctal,          // starts with 0
-        eHex,            // starts with 0x
-        eDefault         // Numbers with a (possible) trailing u or U or l or L for unsigned or long datatypes
-    };
-    // create an instance
-    Representation Mode = eDefault;
-
-
-    // remember position
-    unsigned long n = 0;
-    // eat up whitespace
-    while (std::isspace(s[n])) ++n;
-
-    // determine type
-    if (isHex(s)) {
-        Mode = eHex;
-    } else if (isOct(s)) {
-        Mode = eOctal;
-    }
-
-    // check sign
-    if (s[n] == '-' || s[n] == '+') ++n;
-
-    if (Mode == eHex) {
-        ++n; // 0
-        ++n; // x
-        while (std::isxdigit(s[n]))
-            ++n;
-
-        while (std::tolower(s[n]) == 'u' || std::tolower(s[n]) == 'l') ++n; // unsigned or long (long)
-    }
-    // check octal notation
-    else if (Mode == eOctal) {
-        ++n; // 0
-        while (isOctalDigit(s[n]))
-            ++n;
-
-        while (std::tolower(s[n]) == 'u' || std::tolower(s[n]) == 'l') ++n; // unsigned or long (long)
-    } else if (Mode == eDefault) {
-        // starts with digit
-        bool bStartsWithDigit=false;
-        while (std::isdigit(s[n])) {
-            bStartsWithDigit=true;
-            ++n;
-        };
-
-        while (std::tolower(s[n]) == 'u' || std::tolower(s[n]) == 'l') ++n; // unsigned or long (long)
-
-        if (!bStartsWithDigit)
-            return false;
-    }
-    // eat up whitespace
-    while (std::isspace(s[n]))
-        ++n;
-
-    // if everything goes good, we are at the end of the string and no digits/character
-    // is here --> return true, but if something was found e.g. 12E+12AA return false
-    return (n >= s.length());
+    return isDec(s) || isHex(s) || isOct(s);
 }
 
 std::string MathLib::add(const std::string & first, const std::string & second)
@@ -456,17 +650,30 @@ bool MathLib::isLessEqual(const std::string &first, const std::string &second)
     return toDoubleNumber(first) <= toDoubleNumber(second);
 }
 
+/*! \brief Does the string represent the numerical value of 0?
+ * In case leading or trailing white space is provided, the function
+ * returns false.
+ * Requirement for this function:
+ * - This code is allowed to be slow because of simplicity of the code.
+ *
+ * \param[in] str The string to check. In case the string is empty, the function returns false.
+ * \return Return true in case the string represents a numerical null value.
+ **/
 bool MathLib::isNullValue(const std::string &str)
 {
-    return (str == "-0"        || str == "0"      || str == "+0"
-            || str == "-0.0"   || str == "0.0"    || str == "+0.0"
-            || str == "-0."    || str == "+0."
-            || str == "-0E-00" || str == "-0E+00" || str == "+0E+00" || str == "+0E-00"
-            || str == "-0e-00" || str == "-0e+00" || str == "+0e+00" || str == "+0e-00"
-            || str == "-0E-0");
+    if (str.empty() || (!std::isdigit(static_cast<unsigned char>(str[0])) && (str.size() < 1 || (str[0] != '.' && str[0] != '-' && str[0] != '+'))))
+        return false; // Has to be a number
+
+    for (size_t i = 0; i < str.size(); i++) {
+        if (std::isdigit(static_cast<unsigned char>(str[i])) && str[i] != '0') // May not contain digits other than 0
+            return false;
+        if (str[i] == 'E' || str[i] == 'e')
+            return true;
+    }
+    return true;
 }
 
 bool MathLib::isOctalDigit(char c)
 {
-    return (c == '0' || c == '1' || c == '2' || c == '3' || c == '4' || c == '5' || c == '6' || c == '7');
+    return (c >= '0' && c <= '7');
 }
