@@ -25,7 +25,7 @@
 
 Settings::Settings()
     : _terminate(false),
-      debug(false), debugwarnings(false), debugFalsePositive(false),
+      debug(false), debugwarnings(false), debugFalsePositive(false), exceptionHandling(false),
       inconclusive(false), experimental(false),
       _errorsOnly(false),
       _inlineSuppressions(false),
@@ -34,6 +34,7 @@ Settings::Settings()
       _relativePaths(false),
       _xml(false), _xml_version(1),
       _jobs(1),
+      _loadAverage(0),
       _exitCode(0),
       _showtime(SHOWTIME_NONE),
       _maxConfigs(12),
@@ -111,11 +112,6 @@ std::string Settings::addEnabled(const std::string &str)
     return std::string("");
 }
 
-bool Settings::isEnabled(const std::string &str) const
-{
-    return bool(_enabled.find(str) != _enabled.end());
-}
-
 
 bool Settings::append(const std::string &filename)
 {
