@@ -1,6 +1,6 @@
 /*
  * Cppcheck - A tool for static C/C++ code analysis
- * Copyright (C) 2007-2013 Daniel Marjamäki and Cppcheck team.
+ * Copyright (C) 2007-2014 Daniel Marjamäki and Cppcheck team.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -88,7 +88,7 @@ public:
      * @param templateInstantiations list of template instantiations
      */
     static void useDefaultArgumentValues(const std::list<Token *> &templates,
-                                         const std::list<Token *> &templateInstantiations);
+                                         std::list<Token *> *templateInstantiations);
 
     /**
      * Match template declaration/instantiation
@@ -176,6 +176,5 @@ private:
 };
 
 /// @}
-
 //---------------------------------------------------------------------------
-#endif
+#endif // templatesimplifierH
