@@ -48,7 +48,7 @@ public:
         m_timerResults = tr;
     }
 
-    /** Returns the source file path. e.g. "file.cpp" */
+    /** @return the source file path. e.g. "file.cpp" */
     const std::string& getSourceFilePath() const;
 
     /** Is the code C. Used for bailouts */
@@ -103,10 +103,13 @@ public:
     /**
     * Basic simplification of tokenlist
     *
+    * @param FileName The filename to run; used to do
+    * markup checks.
+    *
     * @return false if there is an error that requires aborting
     * the checking of this file.
     */
-    bool simplifyTokenList1();
+    bool simplifyTokenList1(const char FileName[]);
 
     /**
     * Most aggressive simplification of tokenlist
@@ -184,10 +187,8 @@ public:
     void arraySize();
 
     /** Simplify labels and 'case|default' syntaxes.
-      * @return true if found nothing or the syntax is correct.
-      *         false if syntax is found to be wrong.
       */
-    bool simplifyLabelsCaseDefault();
+    void simplifyLabelsCaseDefault();
 
     /** Remove macros in global scope */
     void removeMacrosInGlobalScope();
@@ -286,13 +287,13 @@ public:
     void simplifyIfSameInnerCondition();
 
     /**
-     * Simplify the "not" and "and" keywords to "!" and "&&"
-     * accordingly.
+     * Simplify the 'C Alternative Tokens'
      * Examples:
-     * - "if (not p)" => "if (!p)"
-     * - "if (p and q)" => "if (p && q)"
+     * "if(s and t)" => "if(s && t)"
+     * "while((r bitand s) and not t)" => while((r & s) && !t)"
+     * "a and_eq b;" => "a &= b;"
      */
-    bool simplifyLogicalOperators();
+    bool simplifyCAlternativeTokens();
 
     /**
      * Simplify comma into a semicolon when possible:
@@ -447,9 +448,8 @@ public:
     /**
      * Simplify functions like "void f(x) int x; {"
      * into "void f(int x) {"
-     * @return false only if there's a syntax error
      */
-    bool simplifyFunctionParameters();
+    void simplifyFunctionParameters();
 
     /**
      * Simplify templates
@@ -490,11 +490,11 @@ public:
 
     void simplifyDefaultAndDeleteInsideClass();
 
-    bool hasComplicatedSyntaxErrorsInTemplates();
+    void findComplicatedSyntaxErrorsInTemplates();
 
     /**
      * Simplify e.g. 'atol("0")' into '0'
-     * @return returns true if simplifcations performed and false otherwise.
+     * @return true if simplifcations performed and false otherwise.
      */
     bool simplifyMathFunctions();
 
@@ -561,11 +561,8 @@ public:
 
     /**
      * Setup links for tokens so that one can call Token::link().
-     *
-     * @return false if there was a mismatch with tokens, this
-     * should mean that source code was not valid.
      */
-    bool createLinks();
+    void createLinks();
 
     /**
      * Setup links between < and >.
@@ -584,9 +581,8 @@ public:
     /**
      * assert that tokens are ok - used during debugging for example
      * to catch problems in simplifyTokenList.
-     * @return always true.
      */
-    bool validate() const;
+    void validate() const;
 
     /**
      * Remove __declspec()
@@ -716,6 +712,8 @@ public:
     void createSymbolDatabase();
     void deleteSymbolDatabase();
 
+    void printDebugOutput() const;
+
     Token *deleteInvalidTypedef(Token *typeDef);
 
     /**
@@ -735,7 +733,7 @@ public:
     /**
      * Output list of unknown types.
      */
-    void printUnknownTypes();
+    void printUnknownTypes() const;
 
 
     /**
@@ -778,6 +776,14 @@ public:
     */
     static bool isTwoNumber(const std::string &s);
 
+    /**
+    * Helper function to check for start of function execution scope.
+    * Do not use this in checks.  Use the symbol database.
+    * @param tok --> pointer to end parentheses of parameter list
+    * @return pointer to start brace of function scope or nullptr if not start.
+    */
+    static const Token * startOfExecutableScope(const Token * tok);
+
 private:
     /** Disable copy constructor, no implementation */
     Tokenizer(const Tokenizer &);
@@ -785,6 +791,11 @@ private:
     /** Disable assignment operator, no implementation */
     Tokenizer &operator=(const Tokenizer &);
 
+    static Token * startOfFunction(Token * tok);
+    static Token * startOfExecutableScope(Token * tok) {
+        return const_cast<Token*>(startOfExecutableScope(const_cast<const Token *>(tok)));
+    }
+
     /** settings */
     const Settings * _settings;
 
