@@ -31,6 +31,12 @@
 #include <stack>
 
 
+// How many compileExpression recursions are allowed?
+// For practical code this could be endless. But in some special torture test
+// there needs to be a limit.
+static const unsigned int AST_MAX_DEPTH = 50U;
+
+
 TokenList::TokenList(const Settings* settings) :
     _front(0),
     _back(0),
@@ -62,7 +68,7 @@ unsigned int TokenList::appendFileIfNew(const std::string &fileName)
             return i;
 
     // The "_files" vector remembers what files have been tokenized..
-    _files.push_back(Path::simplifyPath(fileName.c_str()));
+    _files.push_back(Path::simplifyPath(fileName));
     return static_cast<unsigned int>(_files.size() - 1);
 }
 
@@ -79,43 +85,44 @@ void TokenList::deleteTokens(Token *tok)
 // add a token.
 //---------------------------------------------------------------------------
 
-void TokenList::addtoken(const char str[], const unsigned int lineno, const unsigned int fileno, bool split)
+void TokenList::addtoken(const std::string & str, const unsigned int lineno, const unsigned int fileno, bool split)
 {
-    if (str[0] == 0)
+    if (str.empty())
         return;
 
     // If token contains # characters, split it up
-    if (split && std::strstr(str, "##")) {
-        std::string temp;
-        for (unsigned int i = 0; str[i]; ++i) {
-            if (std::strncmp(&str[i], "##", 2) == 0) {
-                addtoken(temp.c_str(), lineno, fileno, false);
-                temp.clear();
-                addtoken("##", lineno, fileno, false);
-                ++i;
-            } else
-                temp += str[i];
+    if (split) {
+        size_t begin = 0;
+        size_t end = 0;
+        while ((end = str.find("##", begin)) != std::string::npos) {
+            addtoken(str.substr(begin, end - begin), lineno, fileno, false);
+            addtoken("##", lineno, fileno, false);
+            begin = end+2;
+        }
+        if (begin != 0) {
+            addtoken(str.substr(begin), lineno, fileno, false);
+            return;
         }
-        addtoken(temp.c_str(), lineno, fileno, false);
-        return;
     }
 
     // Replace hexadecimal value with decimal
-    std::ostringstream str2;
+    std::string str2;
     if (MathLib::isHex(str) || MathLib::isOct(str) || MathLib::isBin(str)) {
-        str2 << MathLib::toLongNumber(str);
-    } else if (std::strncmp(str, "_Bool", 5) == 0) {
-        str2 << "bool";
+        std::ostringstream str2stream;
+        str2stream << MathLib::toLongNumber(str);
+        str2 = str2stream.str();
+    } else if (str.compare(0, 5, "_Bool") == 0) {
+        str2 = "bool";
     } else {
-        str2 << str;
+        str2 = str;
     }
 
     if (_back) {
-        _back->insertToken(str2.str());
+        _back->insertToken(str2);
     } else {
         _front = new Token(&_back);
         _back = _front;
-        _back->str(str2.str());
+        _back->str(str2);
     }
 
     _back->linenr(lineno);
@@ -138,10 +145,7 @@ void TokenList::addtoken(const Token * tok, const unsigned int lineno, const uns
 
     _back->linenr(lineno);
     _back->fileIndex(fileno);
-    _back->isUnsigned(tok->isUnsigned());
-    _back->isSigned(tok->isSigned());
-    _back->isLong(tok->isLong());
-    _back->isAttributeUnused(tok->isAttributeUnused());
+    _back->flags(tok->flags());
 }
 //---------------------------------------------------------------------------
 // InsertTokens - Copy and insert tokens
@@ -167,11 +171,7 @@ void TokenList::insertTokens(Token *dest, const Token *src, unsigned int n)
         dest->linenr(src->linenr());
         dest->varId(src->varId());
         dest->type(src->type());
-        dest->isUnsigned(src->isUnsigned());
-        dest->isSigned(src->isSigned());
-        dest->isPointerCompare(src->isPointerCompare());
-        dest->isLong(src->isLong());
-        dest->isAttributeUnused(src->isAttributeUnused());
+        dest->flags(src->flags());
         src  = src->next();
         --n;
     }
@@ -207,12 +207,12 @@ bool TokenList::createTokens(std::istream &code, const std::string& file0)
     bool expandedMacro = false;
 
     // Read one byte at a time from code and create tokens
-    for (char ch = (char)code.get(); code.good(); ch = (char)code.get()) {
+    for (char ch = (char)code.get(); code.good() && ch; ch = (char)code.get()) {
         if (ch == Preprocessor::macroChar) {
             while (code.peek() == Preprocessor::macroChar)
                 code.get();
             if (!CurrentToken.empty()) {
-                addtoken(CurrentToken.c_str(), lineno, FileIndex, true);
+                addtoken(CurrentToken, lineno, FileIndex, true);
                 _back->isExpandedMacro(expandedMacro);
             }
             CurrentToken.clear();
@@ -255,12 +255,12 @@ bool TokenList::createTokens(std::istream &code, const std::string& file0)
                 lineno = 0;
             } else {
                 // Add previous token
-                addtoken(CurrentToken.c_str(), lineno, FileIndex);
+                addtoken(CurrentToken, lineno, FileIndex);
                 if (!CurrentToken.empty())
                     _back->isExpandedMacro(expandedMacro);
 
                 // Add content of the string
-                addtoken(line.c_str(), lineno, FileIndex);
+                addtoken(line, lineno, FileIndex);
                 if (!line.empty())
                     _back->isExpandedMacro(expandedMacro);
             }
@@ -326,7 +326,7 @@ bool TokenList::createTokens(std::istream &code, const std::string& file0)
                 continue;
             }
 
-            addtoken(CurrentToken.c_str(), lineno, FileIndex, true);
+            addtoken(CurrentToken, lineno, FileIndex, true);
             if (!CurrentToken.empty()) {
                 _back->isExpandedMacro(expandedMacro);
                 expandedMacro = false;
@@ -348,7 +348,7 @@ bool TokenList::createTokens(std::istream &code, const std::string& file0)
             // Add "++", "--", ">>" or ... token
             if (std::strchr("+-<>=:&|", ch) && (code.peek() == ch))
                 CurrentToken += (char)code.get();
-            addtoken(CurrentToken.c_str(), lineno, FileIndex);
+            addtoken(CurrentToken, lineno, FileIndex);
             _back->isExpandedMacro(expandedMacro);
             CurrentToken.clear();
             expandedMacro = false;
@@ -357,7 +357,7 @@ bool TokenList::createTokens(std::istream &code, const std::string& file0)
 
         CurrentToken += ch;
     }
-    addtoken(CurrentToken.c_str(), lineno, FileIndex, true);
+    addtoken(CurrentToken, lineno, FileIndex, true);
     if (!CurrentToken.empty())
         _back->isExpandedMacro(expandedMacro);
     _front->assignProgressValues();
@@ -375,19 +375,26 @@ static bool iscast(const Token *tok)
     if (!Token::Match(tok, "( %var%"))
         return false;
 
+    if (Token::Match(tok, "( (| typeof (") && Token::Match(tok->link(), ") %num%"))
+        return true;
+
     for (const Token *tok2 = tok->next(); tok2; tok2 = tok2->next()) {
+        if (tok2->str() == ")")
+            return tok2->previous()->str() == "*" ||
+                   (Token::Match(tok2, ") %any%") &&
+                    (!tok2->next()->isOp() && !Token::Match(tok2->next(), "[[]);,?:.]")));
         if (!Token::Match(tok2, "%var%|*|&|::"))
-            return Token::Match(tok2, ") %any%") && (!tok2->next()->isOp() && !Token::Match(tok2->next(), "[[]);,?:]"));
+            return false;
     }
 
     return false;
 }
 
-static void compileUnaryOp(Token *&tok, void (*f)(Token *&, std::stack<Token*> &), std::stack<Token*> &op)
+static void compileUnaryOp(Token *&tok, void (*f)(Token *&, std::stack<Token*> &, unsigned int depth), std::stack<Token*> &op, unsigned int depth)
 {
     Token *unaryop = tok;
     tok = tok->next();
-    f(tok,op);
+    f(tok,op, depth);
 
     if (!op.empty()) {
         unaryop->astOperand1(op.top());
@@ -396,12 +403,16 @@ static void compileUnaryOp(Token *&tok, void (*f)(Token *&, std::stack<Token*> &
     op.push(unaryop);
 }
 
-static void compileBinOp(Token *&tok, void (*f)(Token *&, std::stack<Token*> &), std::stack<Token*> &op)
+static void compileBinOp(Token *&tok, void (*f)(Token *&, std::stack<Token*> &, unsigned int depth), std::stack<Token*> &op, unsigned int depth)
 {
     Token *binop = tok;
     tok = tok->next();
     if (tok)
-        f(tok,op);
+        f(tok,op, depth);
+
+    // Assignment operators are executed in right-to-left order
+    if (binop->isAssignmentOp() && tok && tok->isAssignmentOp())
+        compileBinOp(tok,f,op,depth);
 
     // TODO: Should we check if op is empty.
     // * Is it better to add assertion that it isn't?
@@ -417,10 +428,10 @@ static void compileBinOp(Token *&tok, void (*f)(Token *&, std::stack<Token*> &),
     op.push(binop);
 }
 
-static void compileDot(Token *&tok, std::stack<Token*> &op);
-static void compileExpression(Token *&tok, std::stack<Token*> &op);
+static void compileDot(Token *&tok, std::stack<Token*> &op, unsigned int depth);
+static void compileExpression(Token *&tok, std::stack<Token*> &op, unsigned int depth);
 
-static void compileTerm(Token *& tok, std::stack<Token*> &op)
+static void compileTerm(Token *& tok, std::stack<Token*> &op, unsigned int depth)
 {
     if (!tok)
         return;
@@ -430,12 +441,12 @@ static void compileTerm(Token *& tok, std::stack<Token*> &op)
         op.push(tok);
         tok = tok->next();
     } else if (Token::Match(tok, "+|-|~|*|&|!")) {
-        compileUnaryOp(tok, compileDot, op);
+        compileUnaryOp(tok, compileDot, op, depth);
     } else if (tok->str() == "return") {
-        compileUnaryOp(tok, compileExpression, op);
+        compileUnaryOp(tok, compileExpression, op, depth);
     } else if (tok->isName()) {
         const bool templatefunc = Token::Match(tok, "%var% <") && Token::simpleMatch(tok->linkAt(1), "> (");
-        if (Token::Match(tok->next(), "++|--")) {  // post increment / decrement
+        if (!Token::Match(tok->previous(), ".|::") && Token::Match(tok->next(), "++|--")) {  // post increment / decrement
             tok = tok->next();
             tok->astOperand1(tok->previous());
             op.push(tok);
@@ -444,50 +455,58 @@ static void compileTerm(Token *& tok, std::stack<Token*> &op)
             op.push(tok);
             tok = tok->next()->link()->next();
             if (!Token::simpleMatch(tok, "{"))
-                compileTerm(tok,op);
+                compileTerm(tok,op, depth);
         } else if (!Token::Match(tok->next(), "(|[") && !templatefunc) {
             op.push(tok);
             tok = tok->next();
+        } else if (Token::Match(tok->previous(), ".|:: %var% [")) {
+            op.push(tok);
+            tok = tok->next();
         } else {
             Token *name = tok;
             Token *par  = templatefunc ? tok->linkAt(1)->next() : tok->next();
+            Token *prev = name;
             tok = par->next();
             if (Token::Match(tok, ")|]")) {
                 par->astOperand1(name);
                 tok = tok->next();
             } else {
-                Token *prev = name;
                 tok = tok->previous();
-                while (Token::Match(tok, "(|[")) {
-                    Token *tok1 = tok;
+            }
+            while (Token::Match(tok, "(|[")) {
+                Token *tok1 = tok;
+                tok = tok->next();
+                while (Token::Match(tok,"%var% %var%")) // example: sizeof(struct S)
                     tok = tok->next();
-                    while (Token::Match(tok,"%var% %var%")) // example: sizeof(struct S)
+                compileExpression(tok, op, depth);
+                if (!op.empty()) {
+                    tok1->astOperand2(op.top());
+                    op.pop();
+                }
+                tok1->astOperand1(prev);
+                prev = tok1;
+                if (Token::Match(tok, "]|)")) {
+                    tok = tok->next();
+                    if (depth==1U && Token::Match(tok,"++|--") && op.empty()) {
+                        tok->astOperand1(tok->previous()->link());
                         tok = tok->next();
-                    compileExpression(tok, op);
-                    if (!op.empty()) {
-                        tok1->astOperand2(op.top());
-                        op.pop();
                     }
-                    tok1->astOperand1(prev);
-                    prev = tok1;
-                    if (Token::Match(tok, "]|)"))
-                        tok = tok->next();
                 }
             }
             op.push(par);
         }
     } else if (Token::Match(tok, "++|--")) {
         bool pre = false;
-        if (tok->next() && tok->next()->isName())
+        if (Token::Match(tok->next(), "%var%|("))
             pre = true;
-        else if (!op.empty() && !op.top()->isOp())
+        else if (!op.empty() && !Token::Match(tok->previous(), "(|[") && !op.top()->isOp())
             pre = false;
         else
             pre = true;
 
         if (pre) {
             // pre increment/decrement
-            compileUnaryOp(tok, compileDot, op);
+            compileUnaryOp(tok, compileDot, op, depth);
         } else {
             // post increment/decrement
             tok->astOperand1(op.top());
@@ -499,7 +518,7 @@ static void compileTerm(Token *& tok, std::stack<Token*> &op)
         if (iscast(tok)) {
             Token *unaryop = tok;
             tok = tok->link()->next();
-            compileDot(tok,op);
+            compileDot(tok,op, depth);
 
             if (!op.empty()) {
                 unaryop->astOperand1(op.top());
@@ -510,14 +529,24 @@ static void compileTerm(Token *& tok, std::stack<Token*> &op)
             // Parenthesized sub-expression
             Token *nextpar = tok->link()->next();
             tok = tok->next();
-            compileExpression(tok,op);
+            compileExpression(tok,op, depth);
             tok = nextpar;
-            compileBinOp(tok, compileExpression, op);
-            tok = tok->next();
+            if (Token::simpleMatch(tok,"( )")) {
+                if (!op.empty()) {
+                    Token *f = op.top();
+                    op.pop();
+                    tok->astOperand1(f);
+                    op.push(tok);
+                }
+                tok = tok->tokAt(2);
+            } else {
+                compileBinOp(tok, compileExpression, op, depth);
+                tok = tok->next();
+            }
         } else {
             // Parenthesized sub-expression
             tok = tok->next();
-            compileExpression(tok,op);
+            compileExpression(tok,op, depth);
             tok = tok->next();
         }
     } else if (tok->str() == "{") {
@@ -526,175 +555,189 @@ static void compileTerm(Token *& tok, std::stack<Token*> &op)
     }
 }
 
-static void compileScope(Token *&tok, std::stack<Token*> &op)
+static void compileScope(Token *&tok, std::stack<Token*> &op, unsigned int depth)
 {
-    compileTerm(tok,op);
+    compileTerm(tok,op, depth);
     while (tok) {
         if (tok->str() == "::") {
             if (tok->previous() && tok->previous()->isName())
-                compileBinOp(tok, compileTerm, op);
+                compileBinOp(tok, compileTerm, op, depth);
             else
-                compileUnaryOp(tok, compileDot, op);
+                compileUnaryOp(tok, compileDot, op, depth);
+            if (depth==1U && Token::Match(tok,"++|--"))
+                compileTerm(tok,op,depth);
         } else break;
     }
 }
 
-static void compileParAndBrackets(Token *&tok, std::stack<Token*> &op)
+static void compileDot(Token *&tok, std::stack<Token*> &op, unsigned int depth)
 {
-    compileScope(tok,op);
-    while (tok) {
-        if (tok->str() == "[") {
-            compileBinOp(tok, compileScope, op);
-        } else break;
-    }
-}
-
-static void compileDot(Token *&tok, std::stack<Token*> &op)
-{
-    compileParAndBrackets(tok,op);
+    compileScope(tok,op, depth);
     while (tok) {
         if (tok->str() == ".") {
-            compileBinOp(tok, compileParAndBrackets, op);
+            compileBinOp(tok, compileScope, op, depth);
+            if (depth==1U && Token::Match(tok,"++|--"))
+                compileTerm(tok,op,depth);
         } else break;
     }
 }
 
-static void compileMulDiv(Token *&tok, std::stack<Token*> &op)
+static void compileBrackets(Token *&tok, std::stack<Token*> &op, unsigned int depth)
 {
-    compileDot(tok,op);
+    compileDot(tok,op, depth);
+    while (tok) {
+        if (tok->str() == ".") { // compile dot and brackets from left to right. Example: "a.b[c]"
+            compileBinOp(tok, compileScope, op, depth);
+            if (depth==1U && Token::Match(tok,"++|--"))
+                compileTerm(tok,op,depth);
+        } else if (tok->str() == "[") {
+            compileBinOp(tok, compileDot, op, depth);
+            tok = tok->next();
+        } else break;
+    }
+}
+
+static void compileMulDiv(Token *&tok, std::stack<Token*> &op, unsigned int depth)
+{
+    compileBrackets(tok,op, depth);
     while (tok) {
         if (Token::Match(tok, "[*/%]")) {
-            if (Token::Match(tok, "* [,)]"))
+            if (Token::Match(tok, "* [*,)]")) {
+                while (tok->next() && tok->str() == "*")
+                    tok = tok->next();
                 break;
-            compileBinOp(tok, compileDot, op);
+            }
+            compileBinOp(tok, compileBrackets, op, depth);
         } else break;
     }
 }
 
-static void compileAddSub(Token *&tok, std::stack<Token*> &op)
+static void compileAddSub(Token *&tok, std::stack<Token*> &op, unsigned int depth)
 {
-    compileMulDiv(tok,op);
+    compileMulDiv(tok,op, depth);
     while (tok) {
         if (Token::Match(tok, "+|-")) {
-            compileBinOp(tok, compileMulDiv, op);
+            compileBinOp(tok, compileMulDiv, op, depth);
         } else break;
     }
 }
 
-static void compileShift(Token *&tok, std::stack<Token*> &op)
+static void compileShift(Token *&tok, std::stack<Token*> &op, unsigned int depth)
 {
-    compileAddSub(tok,op);
+    compileAddSub(tok,op, depth);
     while (tok) {
         if (Token::Match(tok, "<<|>>")) {
-            compileBinOp(tok, compileAddSub, op);
+            compileBinOp(tok, compileAddSub, op, depth);
         } else break;
     }
 }
 
-static void compileRelComp(Token *&tok, std::stack<Token*> &op)
+static void compileRelComp(Token *&tok, std::stack<Token*> &op, unsigned int depth)
 {
-    compileShift(tok,op);
+    compileShift(tok,op, depth);
     while (tok) {
         if (Token::Match(tok, "<|<=|>=|>")) {
-            compileBinOp(tok, compileShift, op);
+            compileBinOp(tok, compileShift, op, depth);
         } else break;
     }
 }
 
-static void compileEqComp(Token *&tok, std::stack<Token*> &op)
+static void compileEqComp(Token *&tok, std::stack<Token*> &op, unsigned int depth)
 {
-    compileRelComp(tok,op);
+    compileRelComp(tok,op, depth);
     while (tok) {
         if (Token::Match(tok, "==|!=")) {
-            compileBinOp(tok, compileRelComp, op);
+            compileBinOp(tok, compileRelComp, op, depth);
         } else break;
     }
 }
 
-static void compileAnd(Token *&tok, std::stack<Token*> &op)
+static void compileAnd(Token *&tok, std::stack<Token*> &op, unsigned int depth)
 {
-    compileEqComp(tok,op);
+    compileEqComp(tok,op, depth);
     while (tok) {
         if (tok->str() == "&") {
-            compileBinOp(tok, compileEqComp, op);
+            compileBinOp(tok, compileEqComp, op, depth);
         } else break;
     }
 }
 
-static void compileXor(Token *&tok, std::stack<Token*> &op)
+static void compileXor(Token *&tok, std::stack<Token*> &op, unsigned int depth)
 {
-    compileAnd(tok,op);
+    compileAnd(tok,op, depth);
     while (tok) {
         if (tok->str() == "^") {
-            compileBinOp(tok, compileAnd, op);
+            compileBinOp(tok, compileAnd, op, depth);
         } else break;
     }
 }
 
-static void compileOr(Token *&tok, std::stack<Token*> &op)
+static void compileOr(Token *&tok, std::stack<Token*> &op, unsigned int depth)
 {
-    compileXor(tok,op);
+    compileXor(tok,op, depth);
     while (tok) {
         if (tok->str() == "|") {
-            compileBinOp(tok, compileXor, op);
+            compileBinOp(tok, compileXor, op, depth);
         } else break;
     }
 }
 
-static void compileLogicAnd(Token *&tok, std::stack<Token*> &op)
+static void compileLogicAnd(Token *&tok, std::stack<Token*> &op, unsigned int depth)
 {
-    compileOr(tok,op);
+    compileOr(tok,op, depth);
     while (tok) {
         if (tok->str() == "&&") {
-            compileBinOp(tok, compileOr, op);
+            compileBinOp(tok, compileOr, op, depth);
         } else break;
     }
 }
 
-static void compileLogicOr(Token *&tok, std::stack<Token*> &op)
+static void compileLogicOr(Token *&tok, std::stack<Token*> &op, unsigned int depth)
 {
-    compileLogicAnd(tok,op);
+    compileLogicAnd(tok,op, depth);
     while (tok) {
         if (tok->str() == "||") {
-            compileBinOp(tok, compileLogicAnd, op);
+            compileBinOp(tok, compileLogicAnd, op, depth);
         } else break;
     }
 }
 
-static void compileTernaryOp(Token *&tok, std::stack<Token*> &op)
+static void compileTernaryOp(Token *&tok, std::stack<Token*> &op, unsigned int depth)
 {
-    compileLogicOr(tok,op);
+    compileLogicOr(tok,op, depth);
     while (tok) {
         if (Token::Match(tok, "[?:]")) {
-            compileBinOp(tok, compileLogicOr, op);
+            compileBinOp(tok, compileLogicOr, op, depth);
         } else break;
     }
 }
 
-static void compileAssign(Token *&tok, std::stack<Token*> &op)
+static void compileAssign(Token *&tok, std::stack<Token*> &op, unsigned int depth)
 {
-    compileTernaryOp(tok,op);
+    compileTernaryOp(tok,op, depth);
     while (tok) {
-        if (tok->str() == "=") {
-            compileBinOp(tok, compileTernaryOp, op);
+        if (tok->isAssignmentOp()) {
+            compileBinOp(tok, compileTernaryOp, op, depth);
         } else break;
     }
 }
 
-static void compileComma(Token *&tok, std::stack<Token*> &op)
+static void compileComma(Token *&tok, std::stack<Token*> &op, unsigned int depth)
 {
-    compileAssign(tok,op);
+    compileAssign(tok,op, depth);
     while (tok) {
         if (tok->str() == ",") {
-            compileBinOp(tok, compileAssign, op);
+            compileBinOp(tok, compileAssign, op, depth);
         } else break;
     }
 }
 
-static void compileExpression(Token *&tok, std::stack<Token*> &op)
+static void compileExpression(Token *&tok, std::stack<Token*> &op, unsigned int depth)
 {
+    if (depth > AST_MAX_DEPTH)
+        return; // ticket #5592
     if (tok)
-        compileComma(tok,op);
+        compileComma(tok,op, depth+1U);
 }
 
 static Token * createAstAtToken(Token *tok)
@@ -708,10 +751,10 @@ static Token * createAstAtToken(Token *tok)
                 tok2 = tok2->link();
                 if (!tok2)
                     break;
-            } else if (Token::Match(tok2, "%var% %op%|(|[|.|=|:|::") || Token::Match(tok2->previous(), "[;{}] %cop%|(")) {
+            } else if (Token::Match(tok2, "%var% %op%|(|[|.|=|:|::") || Token::Match(tok2->previous(), "[(;{}] %cop%|(")) {
                 init1 = tok2;
                 std::stack<Token *> operands;
-                compileExpression(tok2, operands);
+                compileExpression(tok2, operands, 0U);
                 if (tok2->str() == ";" || tok2->str() == ")")
                     break;
                 init1 = 0;
@@ -731,12 +774,12 @@ static Token * createAstAtToken(Token *tok)
         Token * const semicolon1 = tok2;
         tok2 = tok2->next();
         std::stack<Token *> operands2;
-        compileExpression(tok2, operands2);
+        compileExpression(tok2, operands2, 0U);
 
         Token * const semicolon2 = tok2;
         tok2 = tok2->next();
         std::stack<Token *> operands3;
-        compileExpression(tok2, operands3);
+        compileExpression(tok2, operands3, 0U);
 
         if (init != semicolon1)
             semicolon1->astOperand1(const_cast<Token*>(init->astTop()));
@@ -767,7 +810,7 @@ static Token * createAstAtToken(Token *tok)
     if (tok->str() == "return" || !tok->previous() || Token::Match(tok, "%var% %op%|(|[|.|=|::") || Token::Match(tok->previous(), "[;{}] %cop%|( !!{")) {
         std::stack<Token *> operands;
         Token * const tok1 = tok;
-        compileExpression(tok, operands);
+        compileExpression(tok, operands, 0U);
         Token * const endToken = tok;
         if (endToken == tok1)
             return tok1;
