@@ -28,14 +28,19 @@
 #include <stack>
 
 
-static void printvalues(const Token *tok)
-{
-    if (tok->values.empty())
-        std::cout << "empty";
-    for (std::list<ValueFlow::Value>::const_iterator it = tok->values.begin(); it != tok->values.end(); ++it)
-        std::cout << " " << (it->intvalue);
-    std::cout << std::endl;
-}
+static void execute(const Token *expr,
+                    std::map<unsigned int, MathLib::bigint> * const programMemory,
+                    MathLib::bigint *result,
+                    bool *error);
+
+//static void printvalues(const Token *tok)
+//{
+//    if (tok->values.empty())
+//        std::cout << "empty";
+//    for (std::list<ValueFlow::Value>::const_iterator it = tok->values.begin(); it != tok->values.end(); ++it)
+//        std::cout << " " << (it->intvalue);
+//    std::cout << std::endl;
+//}
 
 static void bailout(TokenList *tokenlist, ErrorLogger *errorLogger, const Token *tok, const std::string &what)
 {
@@ -51,7 +56,7 @@ static bool bailoutFunctionPar(const Token *tok, const ValueFlow::Value &value,
         return false;
 
     // address of variable
-    const bool addressOf = tok && Token::Match(tok->previous(), "&");
+    const bool addressOf = tok && Token::simpleMatch(tok->previous(), "&");
 
     // passing variable to subfunction?
     if (Token::Match(tok->tokAt(-2), ") & %var% [,)]") && Token::Match(tok->linkAt(-2)->previous(), "[,(] ("))
@@ -61,6 +66,12 @@ static bool bailoutFunctionPar(const Token *tok, const ValueFlow::Value &value,
     else
         return false;
 
+    // reinterpret_cast etc..
+    if (Token::Match(tok->tokAt(-3), "> ( & %var% ) [,)]") &&
+        tok->linkAt(-3) &&
+        Token::Match(tok->linkAt(-3)->tokAt(-2), "[,(] %type% <"))
+        tok = tok->linkAt(-3);
+
     // goto start of function call and get argnr
     unsigned int argnr = 0;
     while (tok && tok->str() != "(") {
@@ -78,8 +89,8 @@ static bool bailoutFunctionPar(const Token *tok, const ValueFlow::Value &value,
         // if value is 0 and the library says 0 is invalid => do not bailout
         if (value.intvalue==0 && settings->library.isnullargbad(tok->str(), 1+argnr))
             return false;
-        // inconclusive => don't bailout
-        if (inconclusive && !addressOf && settings->inconclusive) {
+        // addressOf => inconclusive
+        if (!addressOf) {
             *inconclusive = true;
             return false;
         }
@@ -94,6 +105,29 @@ static bool bailoutFunctionPar(const Token *tok, const ValueFlow::Value &value,
     return arg && !arg->isConst() && arg->isReference();
 }
 
+/**
+ * Is condition always false when variable has given value?
+ * \param condition   top ast token in condition
+ * \param varid       variable id for variable
+ * \param value       value of variable
+ */
+static bool conditionIsFalse(const Token *condition, unsigned int varid, const ValueFlow::Value &value)
+{
+    if (!condition)
+        return false;
+    if (condition->str() == "&&") {
+        bool result1 = conditionIsFalse(condition->astOperand1(), varid, value);
+        bool result2 = result1 ? true : conditionIsFalse(condition->astOperand2(), varid, value);
+        return result2;
+    }
+    std::map<unsigned int, MathLib::bigint> programMemory;
+    programMemory[varid] = value.intvalue;
+    MathLib::bigint result = 0;
+    bool error = false;
+    execute(condition, &programMemory, &result, &error);
+    return !error && result == 0;
+}
+
 /**
  * Should value be skipped because it's hidden inside && || or ?: expression.
  * Example: ((x!=NULL) && (*x == 123))
@@ -152,6 +186,23 @@ static bool bailoutSelfAssignment(const Token * const tok)
     return false;
 }
 
+static bool isVariableChanged(const Token *start, const Token *end, const unsigned int varid)
+{
+    for (const Token *tok = start; tok != end; tok = tok->next()) {
+        if (tok->varId() == varid) {
+            if (Token::Match(tok, "%var% ="))
+                return true;
+
+            const Token *parent = tok->astParent();
+            while (parent && parent->str() == ".")
+                parent = parent->astParent();
+            if (Token::Match(parent, "++|--"))
+                return true;
+        }
+    }
+    return false;
+}
+
 /** set ValueFlow value and perform calculations if possible */
 static void setTokenValue(Token* tok, const ValueFlow::Value &value)
 {
@@ -232,12 +283,40 @@ static void valueFlowNumber(TokenList *tokenlist)
     }
 }
 
+static void valueFlowBitAnd(TokenList *tokenlist)
+{
+    for (Token *tok = tokenlist->front(); tok; tok = tok->next()) {
+        if (tok->str() != "&")
+            continue;
+
+        if (!tok->astOperand1() || !tok->astOperand2())
+            continue;
+
+        MathLib::bigint number;
+        if (MathLib::isInt(tok->astOperand1()->str()))
+            number = MathLib::toLongNumber(tok->astOperand1()->str());
+        else if (MathLib::isInt(tok->astOperand2()->str()))
+            number = MathLib::toLongNumber(tok->astOperand2()->str());
+        else
+            continue;
+
+        int bit = 0;
+        while (bit <= 60 && ((1LL<<bit) < number))
+            ++bit;
+
+        if ((1LL<<bit) == number) {
+            setTokenValue(tok, ValueFlow::Value(0));
+            setTokenValue(tok, ValueFlow::Value(number));
+        }
+    }
+}
+
 static void valueFlowBeforeCondition(TokenList *tokenlist, ErrorLogger *errorLogger, const Settings *settings)
 {
     for (Token *tok = tokenlist->front(); tok; tok = tok->next()) {
-        unsigned int varid;
-        MathLib::bigint num;
-        const Variable *var;
+        unsigned int varid=0;
+        MathLib::bigint num=0;
+        const Variable *var=0;
         if (tok->isComparisonOp() && tok->astOperand1() && tok->astOperand2()) {
             if (tok->astOperand1()->isName() && tok->astOperand2()->isNumber()) {
                 varid = tok->astOperand1()->varId();
@@ -279,16 +358,10 @@ static void valueFlowBeforeCondition(TokenList *tokenlist, ErrorLogger *errorLog
                 continue;
 
             if (Token::Match(tok2->previous(), "for|while (")) {
-                const Token *start = tok2->link()->next();
-                const Token *end   = start->link();
+                const Token * const start = tok2->link()->next();
+                const Token * const end   = start->link();
 
-                if (tok2->astOperand2()->str() == ";" &&
-                    tok2->astOperand2()->astOperand2() &&
-                    tok2->astOperand2()->astOperand2()->str() == ";")
-                    start = tok2->astOperand2()->astOperand2();
-
-                if (Token::findmatch(start,"++|-- %varid%",end,varid) ||
-                    Token::findmatch(start,"%varid% ++|--|=",end,varid)) {
+                if (isVariableChanged(start,end,varid)) {
                     varid = 0U;
                     if (settings->debugwarnings)
                         bailout(tokenlist, errorLogger, tok, "variable " + var->nameToken()->str() + " used in loop");
@@ -364,6 +437,14 @@ static void valueFlowBeforeCondition(TokenList *tokenlist, ErrorLogger *errorLog
                     break;
                 }
 
+                if (Token::Match(tok2->previous(), "sizeof|.")) {
+                    const Token *prev = tok2->previous();
+                    while (Token::Match(prev,"%var%|.") && prev->str() != "sizeof")
+                        prev = prev->previous();
+                    if (Token::Match(prev,"sizeof"))
+                        continue;
+                }
+
                 // assigned by subfunction?
                 bool inconclusive = false;
                 if (bailoutFunctionPar(tok2,val2.condition ? val2 : val, settings, &inconclusive)) {
@@ -395,10 +476,22 @@ static void valueFlowBeforeCondition(TokenList *tokenlist, ErrorLogger *errorLog
             if (tok2->str() == ")" && Token::Match(tok2->link()->previous(), "typeof|sizeof ("))
                 tok2 = tok2->link();
 
+            // goto label
+            if (Token::Match(tok2, "[;{}] %var% :")) {
+                if (settings->debugwarnings)
+                    bailout(tokenlist, errorLogger, tok2->next(), "variable " + var->nameToken()->str() + " stopping on goto label");
+                break;
+            }
+
             if (tok2->str() == "}") {
                 if (Token::findmatch(tok2->link(), "%varid%", tok2, varid)) {
-                    if (settings->debugwarnings)
-                        bailout(tokenlist, errorLogger, tok2, "variable " + var->nameToken()->str() + " stopping on }");
+                    if (settings->debugwarnings) {
+                        std::string errmsg = "variable ";
+                        if (var)
+                            errmsg += var->nameToken()->str() + " ";
+                        errmsg += "stopping on }";
+                        bailout(tokenlist, errorLogger, tok2, errmsg);
+                    }
                     break;
                 } else {
                     tok2 = tok2->link();
@@ -406,12 +499,12 @@ static void valueFlowBeforeCondition(TokenList *tokenlist, ErrorLogger *errorLog
             } else if (tok2->str() == "{") {
                 // if variable is assigned in loop don't look before the loop
                 if (tok2->previous() &&
-                    (Token::Match(tok2->previous(), "do") ||
+                    (Token::simpleMatch(tok2->previous(), "do") ||
                      (tok2->strAt(-1) == ")" && Token::Match(tok2->linkAt(-1)->previous(), "for|while (")))) {
 
                     const Token *start = tok2;
                     const Token *end   = start->link();
-                    if (Token::findmatch(start,"++|--| %varid% ++|--|=",end,varid)) {
+                    if (isVariableChanged(start,end,varid)) {
                         if (settings->debugwarnings)
                             bailout(tokenlist, errorLogger, tok2, "variable " + var->nameToken()->str() + " is assigned in loop. so valueflow analysis bailout when start of loop is reached.");
                         break;
@@ -422,7 +515,7 @@ static void valueFlowBeforeCondition(TokenList *tokenlist, ErrorLogger *errorLog
                 if (!var->isLocal()) {
                     if (!Token::Match(tok2->previous(), ")|else|do {"))
                         break;
-                    if (Token::Match(tok2->previous(), ") {") &&
+                    if (Token::simpleMatch(tok2->previous(), ") {") &&
                         !Token::Match(tok2->linkAt(-1)->previous(), "if|for|while ("))
                         break;
                 }
@@ -437,13 +530,6 @@ static void valueFlowBeforeCondition(TokenList *tokenlist, ErrorLogger *errorLog
                     break;
                 }
             }
-
-            // goto label
-            if (Token::Match(tok2, "[;{}] %var% :")) {
-                if (settings->debugwarnings)
-                    bailout(tokenlist, errorLogger, tok2, "variable " + var->nameToken()->str() + " stopping on goto label");
-                break;
-            }
         }
     }
 }
@@ -477,24 +563,60 @@ static void valueFlowAfterAssign(TokenList *tokenlist, ErrorLogger *errorLogger,
             continue;
         std::list<ValueFlow::Value> values = tok->astOperand2()->values;
 
+        const bool constValue = tok->astOperand2()->isNumber();
+        int indentlevel = 0;
         unsigned int number_of_if = 0;
+        int varusagelevel = -1;
+        bool returnStatement = false;  // current statement is a return, stop analysis at the ";"
 
         for (Token *tok2 = tok; tok2 && tok2 != endToken; tok2 = tok2->next()) {
+            if (indentlevel >= 0 && tok2->str() == "{")
+                ++indentlevel;
+            else if (indentlevel >= 0 && tok2->str() == "}")
+                --indentlevel;
+
             if (Token::Match(tok2, "sizeof|typeof|typeid ("))
                 tok2 = tok2->linkAt(1);
 
             // conditional block of code that assigns variable..
-            if (Token::Match(tok2, "%var% (") && Token::Match(tok2->linkAt(1), ") {")) {
+            else if (Token::Match(tok2, "%var% (") && Token::simpleMatch(tok2->linkAt(1), ") {")) {
+                // Should scope be skipped because variable value is checked?
+                bool skip = false;
+                for (std::list<ValueFlow::Value>::iterator it = values.begin(); it != values.end(); ++it) {
+                    if (conditionIsFalse(tok2->next()->astOperand2(), varid, *it)) {
+                        skip = true;
+                        break;
+                    }
+                }
+                if (skip) {
+                    // goto '{'
+                    tok2 = tok2->linkAt(1)->next();
+                    // goto '}'
+                    tok2 = tok2->link();
+                    continue;
+                }
+
                 Token * const start = tok2->linkAt(1)->next();
                 Token * const end   = start->link();
-                if (Token::findmatch(start, "%varid%", end, varid)) {
+                bool varusage = (indentlevel >= 0 && constValue && number_of_if == 0U) ?
+                                isVariableChanged(start,end,varid) :
+                                (nullptr != Token::findmatch(start, "%varid%", end, varid));
+                if (varusage) {
+                    varusagelevel = indentlevel;
+
                     // TODO: don't check noreturn scopes
-                    if (number_of_if > 0U) {
+                    if (number_of_if > 0U || Token::findmatch(tok2, "%varid%", start, varid)) {
                         if (settings->debugwarnings)
                             bailout(tokenlist, errorLogger, tok2, "variable " + var->nameToken()->str() + " is assigned in conditional code");
                         break;
                     }
 
+                    if (var->isStatic()) {
+                        if (settings->debugwarnings)
+                            bailout(tokenlist, errorLogger, tok2, "variable " + var->nameToken()->str() + " bailout when conditional code that contains var is seen");
+                        break;
+                    }
+
                     // Remove conditional values
                     std::list<ValueFlow::Value>::iterator it;
                     for (it = values.begin(); it != values.end();) {
@@ -506,16 +628,15 @@ static void valueFlowAfterAssign(TokenList *tokenlist, ErrorLogger *errorLogger,
                 }
 
                 // noreturn scopes..
-                if (number_of_if > 0 &&
+                if ((number_of_if > 0 || Token::findmatch(tok2, "%varid%", start, varid)) &&
                     (Token::findmatch(start, "return|continue|break", end) ||
-                     (Token::Match(end,"} else {") && Token::findmatch(end, "return|continue|break", end->linkAt(2))))) {
+                     (Token::simpleMatch(end,"} else {") && Token::findmatch(end, "return|continue|break", end->linkAt(2))))) {
                     if (settings->debugwarnings)
                         bailout(tokenlist, errorLogger, tok2, "variable " + var->nameToken()->str() + ". noreturn conditional scope.");
                     break;
                 }
 
-                if (Token::findmatch(start, "++|-- %varid%", end, varid) ||
-                    Token::findmatch(start, "%varid% ++|--|=", end, varid)) {
+                if (isVariableChanged(start, end, varid)) {
                     if (number_of_if == 0 &&
                         Token::simpleMatch(tok2, "if (") &&
                         !(Token::simpleMatch(end, "} else {") &&
@@ -531,7 +652,7 @@ static void valueFlowAfterAssign(TokenList *tokenlist, ErrorLogger *errorLogger,
                 }
             }
 
-            else if (tok2->str() == "}") {
+            else if (tok2->str() == "}" && indentlevel == varusagelevel) {
                 ++number_of_if;
 
                 // Set "conditional" flag for all values
@@ -543,15 +664,21 @@ static void valueFlowAfterAssign(TokenList *tokenlist, ErrorLogger *errorLogger,
                     tok2 = tok2->linkAt(2);
             }
 
-            else if (Token::Match(tok2, "break|continue")) {
+            else if (indentlevel <= 0 && Token::Match(tok2, "break|continue|goto")) {
                 if (settings->debugwarnings)
                     bailout(tokenlist, errorLogger, tok2, "variable " + var->nameToken()->str() + ". noreturn conditional scope.");
                 break;
             }
 
+            else if (indentlevel <= 0 && tok2->str() == "return")
+                returnStatement = true;
+
+            else if (returnStatement && tok2->str() == ";")
+                break;
+
             if (tok2->varId() == varid) {
                 // bailout: assignment
-                if (Token::Match(tok2->previous(), "!!* %var% =")) {
+                if (Token::Match(tok2->previous(), "!!* %var% %op%") && tok2->next()->isAssignmentOp()) {
                     if (settings->debugwarnings)
                         bailout(tokenlist, errorLogger, tok2, "assignment of " + tok2->str());
                     break;
@@ -609,88 +736,267 @@ static void valueFlowAfterAssign(TokenList *tokenlist, ErrorLogger *errorLogger,
     }
 }
 
+static void execute(const Token *expr,
+                    std::map<unsigned int, MathLib::bigint> * const programMemory,
+                    MathLib::bigint *result,
+                    bool *error)
+{
+    if (!expr)
+        *error = true;
+
+    else if (expr->isNumber())
+        *result = MathLib::toLongNumber(expr->str());
+
+    else if (expr->varId() > 0) {
+        const std::map<unsigned int, MathLib::bigint>::const_iterator var = programMemory->find(expr->varId());
+        if (var == programMemory->end())
+            *error = true;
+        else
+            *result = var->second;
+    }
+
+    else if (expr->isComparisonOp()) {
+        MathLib::bigint result1(0), result2(0);
+        execute(expr->astOperand1(), programMemory, &result1, error);
+        execute(expr->astOperand2(), programMemory, &result2, error);
+        if (expr->str() == "<")
+            *result = result1 < result2;
+        else if (expr->str() == "<=")
+            *result = result1 <= result2;
+        else if (expr->str() == ">")
+            *result = result1 > result2;
+        else if (expr->str() == ">=")
+            *result = result1 >= result2;
+        else if (expr->str() == "==")
+            *result = result1 == result2;
+        else if (expr->str() == "!=")
+            *result = result1 != result2;
+    }
+
+    else if (expr->str() == "=") {
+        execute(expr->astOperand2(), programMemory, result, error);
+        if (!*error && expr->astOperand1() && expr->astOperand1()->varId())
+            (*programMemory)[expr->astOperand1()->varId()] = *result;
+        else
+            *error = true;
+    }
+
+    else if (expr->str() == "++" || expr->str() == "--") {
+        if (!expr->astOperand1() || expr->astOperand1()->varId() == 0U)
+            *error = true;
+        else {
+            std::map<unsigned int, MathLib::bigint>::iterator var = programMemory->find(expr->astOperand1()->varId());
+            if (var == programMemory->end())
+                *error = true;
+            else {
+                if (var->second == 0 &&
+                    expr->str() == "--" &&
+                    expr->astOperand1()->variable() &&
+                    expr->astOperand1()->variable()->typeStartToken()->isUnsigned())
+                    *error = true; // overflow
+                *result = var->second + (expr->str() == "++" ? 1 : -1);
+                var->second = *result;
+            }
+        }
+    }
+
+    else if (expr->isArithmeticalOp() && expr->astOperand1() && expr->astOperand2()) {
+        MathLib::bigint result1(0), result2(0);
+        execute(expr->astOperand1(), programMemory, &result1, error);
+        execute(expr->astOperand2(), programMemory, &result2, error);
+        if (expr->str() == "+")
+            *result = result1 + result2;
+        else if (expr->str() == "-")
+            *result = result1 - result2;
+        else if (expr->str() == "*")
+            *result = result1 * result2;
+        else if (result2 == 0)
+            *error = true;
+        else if (expr->str() == "/")
+            *result = result1 / result2;
+        else if (expr->str() == "%")
+            *result = result1 % result2;
+    }
+
+    else if (expr->str() == "&&") {
+        bool error1 = false;
+        execute(expr->astOperand1(), programMemory, result, &error1);
+        if (!error1 && *result == 0)
+            *result = 0;
+        else {
+            bool error2 = false;
+            execute(expr->astOperand2(), programMemory, result, &error2);
+            if (error1 && error2)
+                *error = true;
+            if (error2)
+                *result = 1;
+            else
+                *result = !!*result;
+        }
+    }
+
+    else if (expr->str() == "||") {
+        execute(expr->astOperand1(), programMemory, result, error);
+        if (*result == 0 && *error == false)
+            execute(expr->astOperand2(), programMemory, result, error);
+    }
+
+    else
+        *error = true;
+}
+
+static bool valueFlowForLoop1(const Token *tok, unsigned int * const varid, MathLib::bigint * const num1, MathLib::bigint * const num2)
+{
+    tok = tok->tokAt(2);
+    if (!Token::Match(tok,"%type%| %var% ="))
+        return false;
+    const Token * const vartok = tok->tokAt(Token::Match(tok, "%var% =") ? 0 : 1);
+    if (vartok->varId() == 0U)
+        return false;
+    *varid = vartok->varId();
+    const Token * const num1tok = Token::Match(vartok->tokAt(2), "%num% ;") ? vartok->tokAt(2) : nullptr;
+    if (num1tok)
+        *num1 = MathLib::toLongNumber(num1tok->str());
+    tok = vartok->tokAt(2);
+    while (Token::Match(tok, "%var%|%num%|%or%|+|-|*|/|&|[|]|("))
+        tok = (tok->str() == "(") ? tok->link()->next() : tok->next();
+    if (!tok || tok->str() != ";")
+        return false;
+    tok = tok->next();
+    const Token *num2tok = nullptr;
+    if (Token::Match(tok, "%varid% <|<=|!=", vartok->varId())) {
+        tok = tok->next();
+        num2tok = tok->astOperand2();
+        if (num2tok && num2tok->str() == "(" && !num2tok->astOperand2())
+            num2tok = num2tok->astOperand1();
+        if (!Token::Match(num2tok, "%num%"))
+            num2tok = 0;
+    }
+    if (!num2tok)
+        return false;
+    *num2 = MathLib::toLongNumber(num2tok->str()) - ((tok->str()=="<=") ? 0 : 1);
+    if (!num1tok)
+        *num1 = *num2;
+    while (tok && tok->str() != ";")
+        tok = tok->next();
+    if (!num2tok || !Token::Match(tok, "; %varid% ++ ) {", vartok->varId()))
+        return false;
+    return true;
+}
+
+static bool valueFlowForLoop2(const Token *tok,
+                              std::map<unsigned int, MathLib::bigint> *memory1,
+                              std::map<unsigned int, MathLib::bigint> *memory2)
+{
+    const Token *firstExpression  = tok->next()->astOperand2()->astOperand1();
+    const Token *secondExpression = tok->next()->astOperand2()->astOperand2()->astOperand1();
+    const Token *thirdExpression = tok->next()->astOperand2()->astOperand2()->astOperand2();
+
+    std::map<unsigned int, MathLib::bigint> programMemory;
+    MathLib::bigint result(0);
+    bool error = false;
+    execute(firstExpression, &programMemory, &result, &error);
+    if (error)
+        return false;
+    execute(secondExpression, &programMemory, &result, &error);
+
+    std::map<unsigned int, MathLib::bigint> startMemory(programMemory);
+    std::map<unsigned int, MathLib::bigint> endMemory;
+
+    unsigned int maxcount = 10000;
+    while (result != 0 && !error && --maxcount) {
+        endMemory = programMemory;
+        execute(thirdExpression, &programMemory, &result, &error);
+        if (!error)
+            execute(secondExpression, &programMemory, &result, &error);
+    }
+
+    memory1->swap(startMemory);
+    if (!error)
+        memory2->swap(endMemory);
+
+    return true;
+}
+
+static void valueFlowForLoopSimplify(Token * const bodyStart, const unsigned int varid, const MathLib::bigint value, TokenList *tokenlist, ErrorLogger *errorLogger, const Settings *settings)
+{
+    const Token * const bodyEnd = bodyStart->link();
+
+    // Is variable modified inside for loop
+    if (isVariableChanged(bodyStart, bodyEnd, varid))
+        return;
+
+    for (Token *tok2 = bodyStart->next(); tok2 != bodyEnd; tok2 = tok2->next()) {
+        if (tok2->varId() == varid) {
+            const Token * parent = tok2->astParent();
+            while (parent) {
+                const Token * const p = parent;
+                parent = parent->astParent();
+                if (parent && parent->str() == ":")
+                    break;
+                if (parent && parent->str() == "?") {
+                    if (parent->astOperand2() != p)
+                        parent = NULL;
+                    break;
+                }
+            }
+            if (parent) {
+                if (settings->debugwarnings)
+                    bailout(tokenlist, errorLogger, tok2, "For loop variable " + tok2->str() + " stopping on ?");
+                continue;
+            }
+
+            ValueFlow::Value value1(value);
+            value1.varId = tok2->varId();
+            setTokenValue(tok2, value1);
+        }
+
+        else if (Token::Match(tok2, ") {") && Token::findmatch(tok2->link(), "%varid%", tok2, varid)) {
+            if (Token::findmatch(tok2, "continue|break|return", tok2->linkAt(1), varid)) {
+                if (settings->debugwarnings)
+                    bailout(tokenlist, errorLogger, tok2, "For loop variable bailout on conditional continue|break|return");
+                break;
+            }
+            if (settings->debugwarnings)
+                bailout(tokenlist, errorLogger, tok2, "For loop variable skipping conditional scope");
+            tok2 = tok2->next()->link();
+            if (Token::Match(tok2, "} else {")) {
+                if (Token::findmatch(tok2, "continue|break|return", tok2->linkAt(2), varid)) {
+                    if (settings->debugwarnings)
+                        bailout(tokenlist, errorLogger, tok2, "For loop variable bailout on conditional continue|break|return");
+                    break;
+                }
+
+                tok2 = tok2->linkAt(2);
+            }
+        }
+    }
+}
+
 static void valueFlowForLoop(TokenList *tokenlist, ErrorLogger *errorLogger, const Settings *settings)
 {
     for (Token *tok = tokenlist->front(); tok; tok = tok->next()) {
-        if (!Token::Match(tok, "for ("))
+        if (!Token::simpleMatch(tok, "for (") ||
+            !Token::simpleMatch(tok->next()->astOperand2(), ";") ||
+            !Token::simpleMatch(tok->next()->astOperand2()->astOperand2(), ";"))
             continue;
 
-        tok = tok->tokAt(2);
-        if (!Token::Match(tok,"%type%| %var% = %num% ;")) { // TODO: don't use %num%
-            if (settings->debugwarnings)
-                bailout(tokenlist, errorLogger, tok, "For loop not handled");
-            continue;
-        }
-        Token * const vartok = tok->tokAt(Token::Match(tok, "%var% =") ? 0 : 1);
-        const MathLib::bigint num1 = MathLib::toLongNumber(vartok->strAt(2));
-        if (vartok->varId() == 0U)
-            continue;
-        tok = vartok->tokAt(4);
-        const Token *num2tok = nullptr;
-        if (Token::Match(tok, "%varid% <|<=|!=", vartok->varId())) {
-            tok = tok->next();
-            num2tok = tok->astOperand2();
-            if (num2tok && num2tok->str() == "(" && !num2tok->astOperand2())
-                num2tok = num2tok->astOperand1();
-            if (!Token::Match(num2tok, "%num%"))
-                num2tok = 0;
-        }
-        if (!num2tok) {
-            if (settings->debugwarnings)
-                bailout(tokenlist, errorLogger, tok, "For loop not handled");
-            continue;
-        }
-        const MathLib::bigint num2 = MathLib::toLongNumber(num2tok ? num2tok->str() : "0") - ((tok->str()=="<=") ? 0 : 1);
-        while (tok && tok->str() != ";")
-            tok = tok->next();
-        if (!num2tok || !Token::Match(tok, "; %varid% ++ ) {", vartok->varId())) {
-            if (settings->debugwarnings)
-                bailout(tokenlist, errorLogger, tok, "For loop not handled");
-            continue;
-        }
+        Token * const bodyStart = tok->linkAt(1)->next();
 
-        Token * const bodyStart = tok->tokAt(4);
-        const Token * const bodyEnd   = bodyStart->link();
+        unsigned int varid(0);
+        MathLib::bigint num1(0), num2(0);
 
-        // Is variable modified inside for loop
-        bool modified = false;
-        for (const Token *tok2 = bodyStart->next(); tok2 != bodyEnd; tok2 = tok2->next()) {
-            if (Token::Match(tok2, "%varid% =", vartok->varId())) {
-                modified = true;
-                break;
-            }
-        }
-        if (modified)
-            continue;
-
-        for (Token *tok2 = bodyStart->next(); tok2 != bodyEnd; tok2 = tok2->next()) {
-            if (tok2->varId() == vartok->varId()) {
-                const Token * parent = tok2->astParent();
-                while (parent) {
-                    const Token * const p = parent;
-                    parent = parent->astParent();
-                    if (parent && parent->str() == "?" && parent->astOperand2() == p)
-                        break;
-                }
-                if (parent) {
-                    if (settings->debugwarnings)
-                        bailout(tokenlist, errorLogger, tok2, "For loop variable " + vartok->str() + " stopping on ?");
-                    continue;
-                }
-
-                ValueFlow::Value value1(num1);
-                value1.varId = tok2->varId();
-                setTokenValue(tok2, value1);
-
-                ValueFlow::Value value2(num2);
-                value2.varId = tok2->varId();
-                setTokenValue(tok2, value2);
-            }
-
-            if (tok2->str() == "{") {
-                if (settings->debugwarnings)
-                    bailout(tokenlist, errorLogger, tok2, "For loop variable " + vartok->str() + " stopping on {");
-                break;
+        if (valueFlowForLoop1(tok, &varid, &num1, &num2)) {
+            valueFlowForLoopSimplify(bodyStart, varid, num1, tokenlist, errorLogger, settings);
+            valueFlowForLoopSimplify(bodyStart, varid, num2, tokenlist, errorLogger, settings);
+        } else {
+            std::map<unsigned int, MathLib::bigint> mem1, mem2;
+            if (valueFlowForLoop2(tok, &mem1, &mem2)) {
+                std::map<unsigned int, MathLib::bigint>::const_iterator it;
+                for (it = mem1.begin(); it != mem1.end(); ++it)
+                    valueFlowForLoopSimplify(bodyStart, it->first, it->second, tokenlist, errorLogger, settings);
+                for (it = mem2.begin(); it != mem2.end(); ++it)
+                    valueFlowForLoopSimplify(bodyStart, it->first, it->second, tokenlist, errorLogger, settings);
             }
         }
     }
@@ -770,6 +1076,7 @@ void ValueFlow::setValues(TokenList *tokenlist, ErrorLogger *errorLogger, const
         tok->values.clear();
 
     valueFlowNumber(tokenlist);
+    valueFlowBitAnd(tokenlist);
     valueFlowForLoop(tokenlist, errorLogger, settings);
     valueFlowBeforeCondition(tokenlist, errorLogger, settings);
     valueFlowAfterAssign(tokenlist, errorLogger, settings);
