@@ -37,6 +37,7 @@ private:
         TEST_CASE(mismatchingBitAnd);  // overlapping bitmasks
         TEST_CASE(compare);            // mismatching LHS/RHS in comparison
         TEST_CASE(multicompare);       // mismatching comparisons
+        TEST_CASE(duplicateIf);        // duplicate conditions in if and else-if
     }
 
     void check(const char code[]) {
@@ -217,6 +218,24 @@ private:
               "    if (y==1) {}\n"
               "}");
         ASSERT_EQUALS("", errout.str());
+
+        // no crash on unary operator& (#5643)
+        check("SdrObject* ApplyGraphicToObject() {\n"
+              "    if (&rHitObject) {}\n"
+              "    else if (rHitObject.IsClosedObj() && !&rHitObject) { }\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+
+        // #5695: increment
+        check("void f(int a0, int n) {\n"
+              "  int c = a0 & 3;\n"
+              "  for (int a = 0; a < n; a++) {\n"
+              "    c++;\n"
+              "    if (c == 4)\n"
+              "      c  = 0;\n"
+              "  }\n"
+              "}\n");
+        ASSERT_EQUALS("", errout.str());
     }
 
     void mismatchingBitAnd() {
@@ -283,6 +302,82 @@ private:
               "}");
         ASSERT_EQUALS("[test.cpp:4]: (style) Expression is always false because 'else if' condition matches previous condition at line 3.\n", errout.str());
     }
+
+    void duplicateIf() {
+        check("void f(int a, int &b) {\n"
+              "    if (a) { b = 1; }\n"
+              "    else { if (a) { b = 2; } }\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:3]: (style) Expression is always false because 'else if' condition matches previous condition at line 2.\n", errout.str());
+
+        check("void f(int a, int &b) {\n"
+              "    if (a) { b = 1; }\n"
+              "    else { if (a) { b = 2; } }\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:3]: (style) Expression is always false because 'else if' condition matches previous condition at line 2.\n", errout.str());
+
+        check("void f(int a, int &b) {\n"
+              "    if (a == 1) { b = 1; }\n"
+              "    else { if (a == 2) { b = 2; }\n"
+              "    else { if (a == 1) { b = 3; } } }\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:4]: (style) Expression is always false because 'else if' condition matches previous condition at line 2.\n", errout.str());
+
+        check("void f(int a, int &b) {\n"
+              "    if (a == 1) { b = 1; }\n"
+              "    else { if (a == 2) { b = 2; }\n"
+              "    else { if (a == 2) { b = 3; } } }\n"
+              "}");
+        ASSERT_EQUALS("[test.cpp:4]: (style) Expression is always false because 'else if' condition matches previous condition at line 3.\n", errout.str());
+
+        check("void f(int a, int &b) {\n"
+              "    if (a++) { b = 1; }\n"
+              "    else { if (a++) { b = 2; }\n"
+              "    else { if (a++) { b = 3; } } }\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+
+        check("void f(int a, int &b) {\n"
+              "    if (!strtok(NULL," ")) { b = 1; }\n"
+              "    else { if (!strtok(NULL," ")) { b = 2; } }\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+
+        check("void f(int a, int &b) {\n"
+              "   x = x / 2;\n"
+              "   if (x < 100) { b = 1; }\n"
+              "   else { x = x / 2; if (x < 100) { b = 2; } }\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+
+        check("void f(int i) {\n"
+              "   if(i == 0x02e2000000 || i == 0xa0c6000000)\n"
+              "       foo(i);\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+
+        // ticket 3689 ( avoid false positive )
+        check("int fitInt(long long int nValue){\n"
+              "    if( nValue < 0x7fffffffLL )\n"
+              "    {\n"
+              "        return 32;\n"
+              "    }\n"
+              "    if( nValue < 0x7fffffffffffLL )\n"
+              "    {\n"
+              "        return 48;\n"
+              "    }\n"
+              "    else {\n"
+              "        if( nValue < 0x7fffffffffffffffLL )\n"
+              "        {\n"
+              "            return 64;\n"
+              "        } else\n"
+              "        {\n"
+              "            return -1;\n"
+              "        }\n"
+              "    }\n"
+              "}");
+        ASSERT_EQUALS("", errout.str());
+    }
 };
 
 REGISTER_TEST(TestAssignIf)
